@@ -1,7 +1,7 @@
 /******************************************************************************
 
-                              Copyright (c) 2014
-                            Lantiq Deutschland GmbH
+                          Copyright (c) 2007-2015
+                     Lantiq Beteiligungs-GmbH & Co. KG
 
   For licensing information, see the file 'LICENSE' in the root folder of
   this software module.
@@ -59,7 +59,6 @@ DSL_Error_t DSL_DRV_BND_ConfigSet(
    DSL_uint8_t nLine;
    DSL_Context_t *pCurrCtx;
 #if defined(INCLUDE_DSL_CPE_API_VRX)
-   DSL_LineFeatureData_t lineFeatureDataCfg;
    DSL_int_t nAutoTcCount = 0, nVdslAtmCount = 0;
    DSL_TcLayerSelection_t nTcMode = DSL_TC_UNKNOWN;
 #endif
