@@ -1,7 +1,7 @@
 /******************************************************************************
 
-                              Copyright (c) 2014
-                            Lantiq Deutschland GmbH
+                          Copyright (c) 2007-2015
+                     Lantiq Beteiligungs-GmbH & Co. KG
 
   For licensing information, see the file 'LICENSE' in the root folder of
   this software module.
@@ -128,6 +128,8 @@ DSL_Error_t DSL_DRV_AutobootThreadStart(
          (pContext, SYS_DBG_MSG"DSL[%02d]: Autoboot thread will be started..."
          DSL_DRV_CRLF, DSL_DEV_NUM(pContext)));
 
+      pContext->bAutobootThreadStarted = DSL_TRUE;
+
       /* Set Autoboot Status*/
       nErrCode = DSL_DRV_AutobootStatusSet(pContext, DSL_AUTOBOOT_STATUS_STARTING,
          DSL_FW_REQUEST_NA);
@@ -196,8 +198,6 @@ static DSL_int_t DSL_DRV_AutobootThreadMain(
       return -1;
    }
 
-   pContext->bAutobootThreadStarted = DSL_TRUE;
-
    DSL_CTX_READ_SCALAR(
       pContext, nErrCode, bAutobootThreadShutdown, bAutobootThreadShutdown);
 
@@ -263,12 +263,12 @@ static DSL_int_t DSL_DRV_AutobootThreadMain(
       (pContext, SYS_DBG_MSG"DSL[%02d]: autoboot ending (%lu)"DSL_DRV_CRLF,
       DSL_DEV_NUM(pContext), DSL_DRV_TimeMSecGet()));
 
-   pContext->bAutobootThreadStarted = DSL_FALSE;
-
    /* Set Autoboot Status*/
    nErrCode = DSL_DRV_AutobootStatusSet(pContext, DSL_AUTOBOOT_STATUS_STOPPED,
       DSL_FW_REQUEST_NA);
 
+   pContext->bAutobootThreadStarted = DSL_FALSE;
+
    DSL_DEBUG(DSL_DBG_MSG,
       (pContext, SYS_DBG_MSG"DSL[%02d]: autoboot complete (%lu)"DSL_DRV_CRLF,
       DSL_DEV_NUM(pContext), DSL_DRV_TimeMSecGet()));
@@ -1200,15 +1200,6 @@ static DSL_Error_t DSL_DRV_AutobootHandleRestart(
 #endif
       /* Reset external trigger*/
       DSL_CTX_WRITE_SCALAR(pContext, nErrCode, bAutobootRestart, DSL_FALSE);
-
-      /* tear down the link immediately */
-      nErrCode = DSL_DRV_LinkFreeze(pContext, XTSE);
-      if( nErrCode != DSL_SUCCESS )
-      {
-         DSL_DEBUG( DSL_DBG_ERR,
-            (pContext, SYS_DBG_ERR"DSL[%02d]: ERROR - Link Freeze failed!"
-            DSL_DRV_CRLF, DSL_DEV_NUM(pContext)));
-      }
    }
 
    DSL_CTX_READ(pContext, nErrCode, bAutobootDisable, bAutobootDisable);
@@ -1400,8 +1391,8 @@ static DSL_Error_t DSL_DRV_AutobootHandleTraining(
                   }
                }
 #endif /* defined(INCLUDE_DSL_CPE_API_VRX)*/
-               DSL_DEBUG(DSL_DBG_ERR, (pContext,
-                  SYS_DBG_ERR"DSL[%02d]: Reboot on training timeout (%d)!!!"
+               DSL_DEBUG(DSL_DBG_WRN, (pContext,
+                  SYS_DBG_WRN"DSL[%02d]: Reboot on training timeout (%d)!!!"
                   DSL_DRV_CRLF, DSL_DEV_NUM(pContext),
                   pContext->nAutobootTimeoutLimit));
 
@@ -1638,6 +1629,13 @@ static DSL_Error_t DSL_DRV_AutobootHandleFwRequest(
 #if defined(INCLUDE_DSL_CPE_API_VRX)
    nFwType = DSL_FW_REQUEST_XDSL;
    DSL_CTX_READ_SCALAR(pContext, nErrCode, pDevCtx->data.nPortMode, nPortMode);
+   if (nPortMode == DSL_PORT_MODE_SINGLE)
+   {
+      /* Terminate link (stop fw) before reset & fw download */
+      DSL_DRV_LinkTerminate(pContext);
+      DSL_DRV_MSecSleep(100);
+   }
+
 #elif defined(INCLUDE_DSL_CPE_API_DANUBE)
    nFwType = DSL_FW_REQUEST_ADSL;
 #endif
@@ -1653,7 +1651,7 @@ static DSL_Error_t DSL_DRV_AutobootHandleFwRequest(
             nErrCode = DSL_DRV_FwDownload(pContext,
                        (DSL_char_t*)pContext->pFirmware,  pContext->nFirmwareSize,
                        (DSL_char_t*)pContext->pFirmware2, pContext->nFirmwareSize2,
-                       &nLoff, &nOff, DSL_TRUE);
+                       &nLoff, &nOff, DSL_TRUE, DSL_FALSE);
 
          if( nErrCode != DSL_SUCCESS )
          {
