@@ -1,7 +1,7 @@
 /******************************************************************************
 
-                              Copyright (c) 2014
-                            Lantiq Deutschland GmbH
+                          Copyright (c) 2007-2015
+                     Lantiq Beteiligungs-GmbH & Co. KG
 
   For licensing information, see the file 'LICENSE' in the root folder of
   this software module.
@@ -28,6 +28,12 @@
 
 #define DSL_DRV_STATIC
 
+#ifdef INCLUDE_DSL_CPE_DEBUG_LOGGER_SUPPORT
+#define NETLINK_DBG_MSG 28
+#define NL_DBG_MSG_GROUP 1
+extern struct sock *nl_debug_sock;
+#endif
+
 static const char* dsl_cpe_api_version = "@(#)DSL CPE API V" DSL_CPE_API_PACKAGE_VERSION;
 
 static DSL_ssize_t DSL_DRV_Write(DSL_DRV_file_t *pFile, const DSL_char_t * pBuf,
@@ -47,6 +53,10 @@ static int DSL_DRV_Release(DSL_DRV_inode_t * ino, DSL_DRV_file_t * fil);
 
 static DSL_uint_t DSL_DRV_Poll(DSL_DRV_file_t *pFile, DSL_DRV_Poll_Table_t *wait);
 
+#ifdef INCLUDE_DSL_CPE_DEBUG_LOGGER_SUPPORT
+static void DSL_DRV_NlSendMsg(DSL_char_t* pMsg);
+#endif
+
 /*DSL_int_t DSL_DRV_Ioctls(DSL_DRV_inode_t * pINode, DSL_DRV_file_t * pFile,
                            unsigned long nCommand, unsigned long nArg);*/
 
@@ -159,7 +169,8 @@ static DSL_ssize_t DSL_DRV_Write(DSL_DRV_file_t *pFile, const DSL_char_t * pBuf,
 
    nErrCode = DSL_DRV_DEV_FwDownload(
       ((DSL_devCtx_t*)(((DSL_OpenContext_t*)pFile->private_data)->pDevCtx))->pContext,
-      pBuf, (DSL_uint32_t)nSize, DSL_NULL, 0, (DSL_int32_t *)pLoff, (DSL_int32_t*)&nOffset, DSL_TRUE);
+      pBuf, (DSL_uint32_t)nSize, DSL_NULL, 0, (DSL_int32_t *)pLoff,
+      (DSL_int32_t*)&nOffset, DSL_TRUE, DSL_TRUE);
 
    if (nErrCode != DSL_SUCCESS)
       return -EIO;
@@ -365,6 +376,42 @@ int DSL_DRV_debug_printf(DSL_Context_t const *pContext, DSL_char_t const *fmt, .
 #ifndef _lint
    DSL_int_t nLength = 0;
    DSL_boolean_t bPrint = DSL_FALSE;
+#ifdef INCLUDE_DSL_CPE_DEBUG_LOGGER_SUPPORT
+#ifndef DSL_DEBUG_DISABLE
+   DSL_char_t debugString[DSL_DBG_MAX_DEBUG_PRINT_CHAR + 1] = {0};
+   va_list ap;   /* points to each unnamed arg in turn */
+
+   if (bPrint == DSL_FALSE)
+   {
+      /* add the debug string itself */
+      va_start(ap, fmt);   /* set ap pointer to 1st unnamed arg */
+      nRet = vsnprintf(&debugString[0], DSL_DBG_MAX_DEBUG_PRINT_CHAR, fmt, ap);
+      va_end(ap);
+
+      if (nRet < 0)
+      {
+         nLength = DSL_DBG_MAX_DEBUG_PRINT_CHAR;
+         printk(KERN_ERR "DSL CPE API: WARNING - printout truncated in "
+                        "'DSL_DRV_debug_printf'!" DSL_DRV_CRLF );
+      }
+      else
+      {
+         nLength = nRet;
+      }
+
+      /* send the formed string to the logger */
+      if (DSL_g_dbgDestination == DSL_DBG_DST_CONSOLE)
+      {
+         nRet = printk("%s",debugString);      
+      }
+      else
+      {
+         DSL_DRV_NlSendMsg(debugString);
+      }
+   }
+#endif /* DSL_DEBUG_DISABLE */
+   return nRet;
+#else
    DSL_char_t msg[DSL_DBG_MAX_DEBUG_PRINT_CHAR + 1] = "\0";
    va_list ap;   /* points to each unnamed arg in turn */
 
@@ -389,7 +436,8 @@ int DSL_DRV_debug_printf(DSL_Context_t const *pContext, DSL_char_t const *fmt, .
    }
 
    va_end(ap);
-#endif /* #ifndef _lint*/
+#endif
+#endif /* _lint */
 
    return nRet;
 }
@@ -442,6 +490,7 @@ int DSL_DRV_ErrorToOS(DSL_Error_t nError)
 DSL_void_t* DSL_DRV_VMalloc(
    DSL_DRV_size_t    nSize)
 {
+   /* VRX500-BU: Better to use vmalloc or vzmalloc here?! */
    return __vmalloc((unsigned long)nSize, GFP_KERNEL, PAGE_KERNEL);
    /*   return vmalloc(nSize);*/
 }
@@ -1118,6 +1167,42 @@ static void DSL_DRV_DebugInit(void)
    return;
 }
 
+#ifdef INCLUDE_DSL_CPE_DEBUG_LOGGER_SUPPORT
+static void DSL_DRV_NlSendMsg(DSL_char_t* pMsg)
+{
+   struct nlmsghdr *pNlMsgHdr;
+   struct sk_buff *pSkbOut;
+   DSL_int_t nMsgSize = 0;
+
+   if(pMsg == IFX_NULL)
+   {
+      printk("ERROR: Debug string is empty!\n");
+      return;
+   }
+
+   nMsgSize = strlen(pMsg);
+
+   pSkbOut = nlmsg_new(nMsgSize, GFP_KERNEL);
+
+   if (!pSkbOut)
+   {
+      printk("Failed to allocate new skb\n");
+      return;
+   }
+   pNlMsgHdr = nlmsg_put(pSkbOut, 0, 0, NLMSG_DONE, nMsgSize, 0);
+   NETLINK_CB(pSkbOut).dst_group = NL_DBG_MSG_GROUP;
+   strncpy(nlmsg_data(pNlMsgHdr), pMsg, nMsgSize);
+
+	if (!nl_debug_sock) {
+		kfree_skb(pSkbOut);
+      printk("Failed to free skb\n");
+      return;
+	}
+   
+   nlmsg_multicast(nl_debug_sock, pSkbOut, 0, NL_DBG_MSG_GROUP, GFP_KERNEL);
+}
+#endif
+
 /* Entry point of driver */
 int __init DSL_ModuleInit(void)
 {
@@ -1164,7 +1249,7 @@ void __exit DSL_ModuleCleanup(void)
    printk("Module will be unloaded"DSL_DRV_CRLF);
 
    unregister_chrdev(nMajorNum, DRV_DSL_CPE_API_DEV_NAME);
-
+   
    DSL_DRV_Cleanup();
 
    return;
