@@ -1,7 +1,7 @@
 /******************************************************************************
 
-                              Copyright (c) 2014
-                            Lantiq Deutschland GmbH
+                          Copyright (c) 2007-2015
+                     Lantiq Beteiligungs-GmbH & Co. KG
 
   For licensing information, see the file 'LICENSE' in the root folder of
   this software module.
@@ -299,8 +299,8 @@ DSL_Error_t DSL_DRV_G997_XTUSystemEnablingStatusGet(
         (nCurrentState != DSL_LINESTATE_LOOPDIAGNOSTIC_ACTIVE))
 #endif
    {
-      DSL_DEBUG(DSL_DBG_ERR,
-         (pContext, SYS_DBG_ERR"DSL[%02d]: ERROR - no data in the current line state!"
+      DSL_DEBUG(DSL_DBG_WRN,
+         (pContext, SYS_DBG_WRN"DSL[%02d]: ERROR - no data in the current line state!"
          DSL_DRV_CRLF, DSL_DEV_NUM(pContext)));
 
       nErrCode = DSL_ERR_DEVICE_NO_DATA;
@@ -436,6 +436,38 @@ DSL_Error_t DSL_DRV_G997_LineInitStatusGet(
 }
 #endif /* INCLUDE_DSL_G997_STATUS*/
 
+#ifdef INCLUDE_DSL_CPE_API_VRX
+/*
+   For a detailed description please refer to the equivalent ioctl
+   \ref DSL_FIO_G997_ATTAINABLE_NDR_STATUS_GET
+*/
+DSL_Error_t DSL_DRV_G997_AttainableNdrStatusGet (
+   DSL_IN DSL_Context_t *pContext,
+   DSL_IN_OUT DSL_G997_AttainableNdrStatus_t *pData)
+{
+   DSL_Error_t nErrCode = DSL_SUCCESS;
+
+   DSL_DEBUG(DSL_DBG_MSG, (pContext,
+      SYS_DBG_MSG"DSL[%02d]: IN - DSL_DRV_G997_AttainableNdrStatusGet"
+      DSL_DRV_CRLF, DSL_DEV_NUM(pContext)));
+
+   DSL_CHECK_POINTER(pContext, pData);
+   DSL_CHECK_ERR_CODE();
+
+   DSL_CHECK_DIRECTION(pData->nDirection);
+   DSL_CHECK_ERR_CODE();
+
+   /* Call device specific implementation*/
+   nErrCode = DSL_DRV_DEV_G997_AttainableNdrStatusGet(pContext, pData);
+
+   DSL_DEBUG(DSL_DBG_MSG, (pContext, SYS_DBG_MSG
+      "DSL[%02d]: OUT - DSL_DRV_G997_AttainableNdrStatusGet, retCode=%d"
+      DSL_DRV_CRLF, DSL_DEV_NUM(pContext), nErrCode));
+
+   return nErrCode;
+}
+#endif /* #ifdef INCLUDE_DSL_CPE_API_VRX*/
+
 /*
    For a detailed description please refer to the equivalent ioctl
    \ref DSL_FIO_G997_LINE_STATUS_GET
@@ -559,11 +591,6 @@ DSL_Error_t DSL_DRV_G997_RateAdaptationConfigSet(
          return DSL_ERR_NOT_SUPPORTED_BY_FIRMWARE;
       }
 #endif /* INCLUDE_DSL_CPE_API_DANUBE*/
-      /* Used for special handling of default SRA value for DSLCPE_SW-768
-         Take care that user defined configuration values have the higher
-         priority here. */
-      DSL_CTX_WRITE_SCALAR(pContext, nErrCode, bDefaultRaModeSet, DSL_TRUE);
-
       /* Update internal Rate Adaptation Mode Settings for the selected
          xDSL mode and direction */
       DSL_CTX_WRITE(pContext, nErrCode,
@@ -619,6 +646,38 @@ DSL_Error_t DSL_DRV_G997_RateAdaptationConfigGet(
 }
 #endif /* INCLUDE_DSL_CONFIG_GET*/
 
+/*
+   For a detailed description please refer to the equivalent ioctl
+   \ref DSL_FIO_G997_RATE_ADAPTATION_STATUS_GET
+*/
+#ifdef INCLUDE_DSL_CPE_API_VRX
+DSL_Error_t DSL_DRV_G997_RateAdaptationStatusGet(
+   DSL_IN DSL_Context_t *pContext,
+   DSL_IN_OUT DSL_G997_RateAdaptationStatus_t *pData)
+{
+   DSL_Error_t nErrCode = DSL_SUCCESS;
+
+   DSL_CHECK_POINTER(pContext, pData);
+   DSL_CHECK_ERR_CODE();
+
+   DSL_CHECK_DIRECTION(pData->nDirection);
+   DSL_CHECK_ERR_CODE();
+
+   DSL_DEBUG(DSL_DBG_MSG,
+      (pContext, SYS_DBG_MSG"DSL[%02d]: IN - DSL_DRV_G997_RateAdaptationStatusGet"
+      DSL_DRV_CRLF, DSL_DEV_NUM(pContext)));
+
+   /* Call device specific implementation*/
+   nErrCode = DSL_DRV_DEV_G997_RateAdaptationStatusGet(pContext, pData);
+
+   DSL_DEBUG(DSL_DBG_MSG,
+      (pContext, SYS_DBG_MSG"DSL[%02d]: OUT - DSL_DRV_G997_RateAdaptationStatusGet, retCode=%d"
+      DSL_DRV_CRLF, DSL_DEV_NUM(pContext), nErrCode));
+
+   return nErrCode;
+}
+#endif /* INCLUDE_DSL_CPE_API_VRX */
+
 /*
    For a detailed description please refer to the equivalent ioctl
    \ref DSL_FIO_G997_CHANNEL_STATUS_GET
