@@ -1,7 +1,7 @@
 /******************************************************************************
 
-                              Copyright (c) 2014
-                            Lantiq Deutschland GmbH
+                          Copyright (c) 2007-2015
+                     Lantiq Beteiligungs-GmbH & Co. KG
 
   For licensing information, see the file 'LICENSE' in the root folder of
   this software module.
@@ -79,8 +79,10 @@ DSL_Error_t DSL_DRV_DEV_G997_SnrAllocationNscGet(
    DSL_IN DSL_Context_t *pContext,
    DSL_IN_OUT DSL_G997_SnrAllocationNsc_t *pData)
 {
-   DSL_Error_t nErrCode = DSL_SUCCESS;
+   DSL_Error_t nErrCode = DSL_SUCCESS,
+               nRetCode = DSL_SUCCESS;
    DSL_LineStateValue_t nCurrentState = DSL_LINESTATE_UNKNOWN;
+   DSL_DEV_VersionCheck_t nVerCheck = DSL_VERSION_ERROR;
 
    DSL_DEBUG(DSL_DBG_MSG, (pContext,SYS_DBG_MSG
       "DSL[%02d]: IN - DSL_DRV_DEV_G997_SnrAllocationNscGet (nDirection=%d)"
@@ -94,31 +96,31 @@ DSL_Error_t DSL_DRV_DEV_G997_SnrAllocationNscGet(
          nCurrentState == DSL_LINESTATE_SHOWTIME_NO_SYNC))
    {
 
-      if (DSL_DRV_VRX_FirmwareXdslModeCheck(pContext, DSL_VRX_FW_VDSL2) &&
-                                           (pData->nDirection == DSL_UPSTREAM))
+      /* Get FW information*/
+      nErrCode = DSL_DRV_VRX_FirmwareVersionCheck(pContext,
+                     DSL_MIN_FW_VERSION_FE_DELT, &nVerCheck);
+      if (nErrCode != DSL_SUCCESS)
+      {
+         DSL_DEBUG(DSL_DBG_ERR, (pContext,
+            SYS_DBG_ERR"DSL[%02d]: ERROR - FW version check failed!"
+            DSL_DRV_CRLF, DSL_DEV_NUM(pContext)));
+         return nErrCode;
+      }
+
+      if ((nVerCheck < DSL_VERSION_EQUAL)
+         && DSL_DRV_VRX_FirmwareXdslModeCheck(pContext, DSL_VRX_FW_VDSL2)
+         && (pData->nDirection == DSL_UPSTREAM))
       {
          nErrCode = DSL_DRV_VRX_TestParamsFeCheck(pContext);
          if (nErrCode >= DSL_SUCCESS)
          {
             if( pContext->DELT_SHOWTIME != DSL_NULL )
             {
-               if(DSL_DRV_MUTEX_LOCK(pContext->dataMutex))
-               {
-                  DSL_DEBUG( DSL_DBG_ERR,
-                     (pContext, SYS_DBG_ERR"DSL[%02d]: Couldn't lock data mutex"
-                     DSL_DRV_CRLF, DSL_DEV_NUM(pContext)));
-
-                  return DSL_ERR_SEMAPHORE_GET;
-               }
-
-               pData->data.snrAllocationNsc.nNumData
-                     = pContext->DELT_SHOWTIME->snrDataUsVdsl.deltSnr.nNumData;
-               /* copy data */
-               memcpy(&pData->data.snrAllocationNsc.nNSCData,
-                      pContext->DELT_SHOWTIME->snrDataUsVdsl.deltSnr.nSCGData,
-                      pData->data.snrAllocationNsc.nNumData);
-
-               DSL_DRV_MUTEX_UNLOCK(pContext->dataMutex);
+               DSL_CTX_NREAD(pContext, nRetCode,
+                             DELT_SHOWTIME->snrDataUsVdsl.deltSnr,
+                             pData->data.snrAllocationNsc,
+                             sizeof(pContext->DELT_SHOWTIME->snrDataUsVdsl.deltSnr));
+               DSL_SET_ERROR_CODE(nRetCode, nErrCode);
             }
             else
             {
@@ -128,6 +130,7 @@ DSL_Error_t DSL_DRV_DEV_G997_SnrAllocationNscGet(
       }
       else
       {
+         /* Get SHOWTIME snr parameter directly from the FW*/
          nErrCode = DSL_DRV_VRX_SendMsgSnrGet(pContext,
                            pData->nDirection, &(pData->data.snrAllocationNsc));
       }
@@ -179,8 +182,8 @@ DSL_Error_t DSL_DRV_DEV_G997_LineStatusPerBandGet(
    {
       nErrCode = DSL_ERR_ONLY_AVAILABLE_IN_SHOWTIME;
 
-      DSL_DEBUG(DSL_DBG_ERR,
-         (pContext, SYS_DBG_ERR"DSL[%02d]: ERROR - Function is only available in the SHOWTIME!"
+      DSL_DEBUG(DSL_DBG_WRN,
+         (pContext, SYS_DBG_WRN"DSL[%02d]: ERROR - Function is only available in the SHOWTIME!"
          DSL_DRV_CRLF, DSL_DEV_NUM(pContext)));
    }
 
@@ -224,8 +227,8 @@ DSL_Error_t DSL_DRV_DEV_G997_UsPowerBackOffStatusGet(
    {
       nErrCode = DSL_ERR_ONLY_AVAILABLE_IN_SHOWTIME;
 
-      DSL_DEBUG(DSL_DBG_ERR,
-         (pContext, SYS_DBG_ERR"DSL[%02d]: ERROR - Function is only available in the SHOWTIME!"
+      DSL_DEBUG(DSL_DBG_WRN,
+         (pContext, SYS_DBG_WRN"DSL[%02d]: ERROR - Function is only available in the SHOWTIME!"
          DSL_DRV_CRLF, DSL_DEV_NUM(pContext)));
    }
 
@@ -285,8 +288,8 @@ DSL_Error_t DSL_DRV_DEV_G997_LineStatusGet(
       {
          nErrCode = DSL_ERR_ONLY_AVAILABLE_IN_SHOWTIME;
 
-         DSL_DEBUG(DSL_DBG_ERR,
-            (pContext, SYS_DBG_ERR"DSL[%02d]: ERROR - Function is only available in the SHOWTIME!"
+         DSL_DEBUG(DSL_DBG_WRN,
+            (pContext, SYS_DBG_WRN"DSL[%02d]: ERROR - Function is only available in the SHOWTIME!"
             DSL_DRV_CRLF, DSL_DEV_NUM(pContext)));
       }
    }
@@ -458,8 +461,8 @@ DSL_Error_t DSL_DRV_DEV_G997_ChannelStatusGet(
    }
    else
    {
-      DSL_DEBUG(DSL_DBG_ERR,
-         (pContext, SYS_DBG_ERR"DSL[%02d]: ERROR - Function is only available in the SHOWTIME!"
+      DSL_DEBUG(DSL_DBG_WRN,
+         (pContext, SYS_DBG_WRN"DSL[%02d]: ERROR - Function is only available in the SHOWTIME!"
          DSL_DRV_CRLF, DSL_DEV_NUM(pContext)));
 
       nErrCode = DSL_ERR_ONLY_AVAILABLE_IN_SHOWTIME;
@@ -511,8 +514,8 @@ DSL_Error_t DSL_DRV_DEV_G997_FramingParameterStatusGet(
    if ( (nCurrentState != DSL_LINESTATE_SHOWTIME_TC_SYNC) &&
         (nCurrentState != DSL_LINESTATE_SHOWTIME_NO_SYNC) )
    {
-      DSL_DEBUG(DSL_DBG_ERR,
-         (pContext, SYS_DBG_ERR"DSL[%02d]: ERROR - Function is only available in the SHOWTIME!"
+      DSL_DEBUG(DSL_DBG_WRN,
+         (pContext, SYS_DBG_WRN"DSL[%02d]: ERROR - Function is only available in the SHOWTIME!"
          DSL_DRV_CRLF, DSL_DEV_NUM(pContext)));
 
       return DSL_ERR_ONLY_AVAILABLE_IN_SHOWTIME;
@@ -622,11 +625,11 @@ DSL_Error_t DSL_DRV_DEV_G997_DeltHlinGet(
       {
          if (nDirection == DSL_DOWNSTREAM)
          {
-            DSL_CTX_READ(pContext, nErrCode, DELT->hlinDataDs, pData);
+            DSL_CTX_NREAD(pContext, nErrCode, DELT->hlinDataDs, *pData, sizeof(pContext->DELT->hlinDataDs));
          }
          else
          {
-            DSL_CTX_READ(pContext, nErrCode, DELT->hlinDataUs, pData);
+            DSL_CTX_NREAD(pContext, nErrCode, DELT->hlinDataUs, *pData, sizeof(pContext->DELT->hlinDataDs));
          }
       }
       else
@@ -659,9 +662,11 @@ DSL_Error_t DSL_DRV_DEV_G997_DeltHlogGet(
    DSL_IN DSL_DeltDataType_t nDeltDataType,
    DSL_OUT DSL_G997_DeltHlogData_t *pData)
 {
-   DSL_Error_t nErrCode = DSL_SUCCESS;
+   DSL_Error_t nErrCode = DSL_SUCCESS,
+               nRetCode = DSL_SUCCESS;
    DSL_LineStateValue_t nCurrentState = DSL_LINESTATE_UNKNOWN;
    ACK_TestParamsAuxDS_Get_t  sAck;
+   DSL_DEV_VersionCheck_t nVerCheck = DSL_VERSION_ERROR;
 
    DSL_CHECK_POINTER(pContext, pData);
    DSL_CHECK_ERR_CODE();
@@ -691,8 +696,20 @@ DSL_Error_t DSL_DRV_DEV_G997_DeltHlogGet(
                DSL_DRV_CRLF, DSL_DEV_NUM(pContext), nDirection));
          }
 
-         if (DSL_DRV_VRX_FirmwareXdslModeCheck(pContext, DSL_VRX_FW_VDSL2)
-                                               && (nDirection == DSL_UPSTREAM))
+         /* Get FW information*/
+         nErrCode = DSL_DRV_VRX_FirmwareVersionCheck(pContext,
+                        DSL_MIN_FW_VERSION_FE_DELT, &nVerCheck);
+         if (nErrCode != DSL_SUCCESS)
+         {
+            DSL_DEBUG(DSL_DBG_ERR, (pContext,
+               SYS_DBG_ERR"DSL[%02d]: ERROR - FW version check failed!"
+               DSL_DRV_CRLF, DSL_DEV_NUM(pContext)));
+            return nErrCode;
+         }
+
+         if ((nVerCheck < DSL_VERSION_EQUAL)
+            && DSL_DRV_VRX_FirmwareXdslModeCheck(pContext, DSL_VRX_FW_VDSL2)
+            && (nDirection == DSL_UPSTREAM))
          {
             nErrCode = DSL_DRV_VRX_TestParamsFeCheck(pContext);
             if (nErrCode >= DSL_SUCCESS)
@@ -700,7 +717,10 @@ DSL_Error_t DSL_DRV_DEV_G997_DeltHlogGet(
                if(pContext->DELT_SHOWTIME != DSL_NULL)
                {
                   /* Get FE showtime parameters from the internal buffer*/
-                  DSL_CTX_READ(pContext, nErrCode, DELT_SHOWTIME->hlogDataUsVdsl, pData);
+                  DSL_CTX_NREAD(pContext, nRetCode,
+                                DELT_SHOWTIME->hlogDataUsVdsl, *pData,
+                                sizeof(pContext->DELT_SHOWTIME->hlogDataUsVdsl));
+                  DSL_SET_ERROR_CODE(nRetCode, nErrCode);
                }
                else
                {
@@ -728,11 +748,15 @@ DSL_Error_t DSL_DRV_DEV_G997_DeltHlogGet(
       {
          if (nDirection == DSL_DOWNSTREAM)
          {
-            DSL_CTX_READ(pContext, nErrCode, DELT->hlogDataDs, pData);
+            DSL_CTX_NREAD(pContext, nErrCode,
+                          DELT->hlogDataDs, *pData,
+                          sizeof(pContext->DELT->hlogDataDs));
          }
          else
          {
-            DSL_CTX_READ(pContext, nErrCode, DELT->hlogDataUs, pData);
+            DSL_CTX_NREAD(pContext, nErrCode,
+                          DELT->hlogDataUs, *pData,
+                          sizeof(pContext->DELT->hlogDataUs));
          }
       }
       else
@@ -765,9 +789,11 @@ DSL_Error_t DSL_DRV_DEV_G997_DeltQLNGet(
    DSL_IN DSL_DeltDataType_t nDeltDataType,
    DSL_OUT DSL_G997_DeltQlnData_t *pData)
 {
-   DSL_Error_t nErrCode = DSL_SUCCESS;
+   DSL_Error_t nErrCode = DSL_SUCCESS,
+               nRetCode = DSL_SUCCESS;
    DSL_LineStateValue_t nCurrentState = DSL_LINESTATE_UNKNOWN;
    ACK_TestParamsAuxDS_Get_t  sAck;
+   DSL_DEV_VersionCheck_t nVerCheck = DSL_VERSION_ERROR;
 
    DSL_CHECK_POINTER(pContext, pData);
    DSL_CHECK_ERR_CODE();
@@ -797,8 +823,20 @@ DSL_Error_t DSL_DRV_DEV_G997_DeltQLNGet(
                DSL_DRV_CRLF, DSL_DEV_NUM(pContext), nDirection));
          }
 
-         if (DSL_DRV_VRX_FirmwareXdslModeCheck(pContext, DSL_VRX_FW_VDSL2)
-                                               && (nDirection == DSL_UPSTREAM))
+         /* Get FW information*/
+         nErrCode = DSL_DRV_VRX_FirmwareVersionCheck(pContext,
+                        DSL_MIN_FW_VERSION_FE_DELT, &nVerCheck);
+         if (nErrCode != DSL_SUCCESS)
+         {
+            DSL_DEBUG(DSL_DBG_ERR, (pContext,
+               SYS_DBG_ERR"DSL[%02d]: ERROR - FW version check failed!"
+               DSL_DRV_CRLF, DSL_DEV_NUM(pContext)));
+            return nErrCode;
+         }
+
+         if ((nVerCheck < DSL_VERSION_EQUAL)
+            && DSL_DRV_VRX_FirmwareXdslModeCheck(pContext, DSL_VRX_FW_VDSL2)
+            && (nDirection == DSL_UPSTREAM))
          {
             nErrCode = DSL_DRV_VRX_TestParamsFeCheck(pContext);
             if (nErrCode >= DSL_SUCCESS)
@@ -806,7 +844,10 @@ DSL_Error_t DSL_DRV_DEV_G997_DeltQLNGet(
                if(pContext->DELT_SHOWTIME != DSL_NULL)
                {
                   /* Get FE showtime parameters from the internal buffer*/
-                  DSL_CTX_READ(pContext, nErrCode, DELT_SHOWTIME->qlnDataUsVdsl, pData);
+                  DSL_CTX_NREAD(pContext, nRetCode,
+                                DELT_SHOWTIME->qlnDataUsVdsl, *pData,
+                                sizeof(pContext->DELT_SHOWTIME->qlnDataUsVdsl));
+                  DSL_SET_ERROR_CODE(nRetCode, nErrCode);
                }
                else
                {
@@ -834,11 +875,15 @@ DSL_Error_t DSL_DRV_DEV_G997_DeltQLNGet(
       {
          if (nDirection == DSL_DOWNSTREAM)
          {
-            DSL_CTX_READ(pContext, nErrCode, DELT->qlnDataDs, pData);
+            DSL_CTX_NREAD(pContext, nErrCode,
+                          DELT->qlnDataDs, *pData,
+                          sizeof(pContext->DELT->qlnDataDs));
          }
          else
          {
-            DSL_CTX_READ(pContext, nErrCode, DELT->qlnDataUs, pData);
+            DSL_CTX_NREAD(pContext, nErrCode,
+                          DELT->qlnDataUs, *pData,
+                          sizeof(pContext->DELT->qlnDataUs));
          }
       }
       else
@@ -872,9 +917,11 @@ DSL_Error_t DSL_DRV_DEV_G997_DeltSNRGet(
    DSL_IN DSL_DeltDataType_t nDeltDataType,
    DSL_OUT DSL_G997_DeltSnrData_t *pData)
 {
-   DSL_Error_t nErrCode = DSL_SUCCESS;
+   DSL_Error_t nErrCode = DSL_SUCCESS,
+               nRetCode = DSL_SUCCESS;
    DSL_LineStateValue_t nCurrentState = DSL_LINESTATE_UNKNOWN;
    ACK_TestParamsAuxDS_Get_t  sAck;
+   DSL_DEV_VersionCheck_t nVerCheck = DSL_VERSION_ERROR;
 
    DSL_CHECK_POINTER(pContext, pData);
    DSL_CHECK_ERR_CODE();
@@ -905,8 +952,20 @@ DSL_Error_t DSL_DRV_DEV_G997_DeltSNRGet(
                DSL_DRV_CRLF, DSL_DEV_NUM(pContext), nDirection));
          }
 
-         if (DSL_DRV_VRX_FirmwareXdslModeCheck(pContext, DSL_VRX_FW_VDSL2)
-                                               && (nDirection == DSL_UPSTREAM))
+         /* Get FW information*/
+         nErrCode = DSL_DRV_VRX_FirmwareVersionCheck(pContext,
+                        DSL_MIN_FW_VERSION_FE_DELT, &nVerCheck);
+         if (nErrCode != DSL_SUCCESS)
+         {
+            DSL_DEBUG(DSL_DBG_ERR, (pContext,
+               SYS_DBG_ERR"DSL[%02d]: ERROR - FW version check failed!"
+               DSL_DRV_CRLF, DSL_DEV_NUM(pContext)));
+            return nErrCode;
+         }
+
+         if ((nVerCheck < DSL_VERSION_EQUAL)
+            && DSL_DRV_VRX_FirmwareXdslModeCheck(pContext, DSL_VRX_FW_VDSL2)
+            && (nDirection == DSL_UPSTREAM))
          {
             nErrCode = DSL_DRV_VRX_TestParamsFeCheck(pContext);
             if (nErrCode >= DSL_SUCCESS)
@@ -914,7 +973,10 @@ DSL_Error_t DSL_DRV_DEV_G997_DeltSNRGet(
                if(pContext->DELT_SHOWTIME != DSL_NULL)
                {
                   /* Get FE showtime parameters from the internal buffer*/
-                  DSL_CTX_READ(pContext, nErrCode, DELT_SHOWTIME->snrDataUsVdsl, pData);
+                  DSL_CTX_NREAD(pContext, nRetCode,
+                                DELT_SHOWTIME->snrDataUsVdsl, *pData,
+                                sizeof(pContext->DELT_SHOWTIME->snrDataUsVdsl));
+                  DSL_SET_ERROR_CODE(nRetCode, nErrCode);
                }
                else
                {
@@ -924,7 +986,9 @@ DSL_Error_t DSL_DRV_DEV_G997_DeltSNRGet(
          }
          else
          {
-            nErrCode = DSL_DRV_VRX_SendMsgSnrGet(pContext, nDirection, &(pData->deltSnr));
+            /* Get SHOWTIME snr parameter directly from the FW*/
+            nErrCode = DSL_DRV_VRX_SendMsgSnrPerGroupesGet(pContext, nDirection,
+                                    (DSL_uint8_t)sAck.SNRG, &(pData->deltSnr));
 
             pData->nGroupSize       = (DSL_uint8_t)sAck.SNRG;
             pData->nMeasurementTime = sAck.SNRMT;
@@ -942,11 +1006,18 @@ DSL_Error_t DSL_DRV_DEV_G997_DeltSNRGet(
       {
          if (nDirection == DSL_DOWNSTREAM)
          {
-            DSL_CTX_READ(pContext, nErrCode, DELT->snrDataDs, pData);
+            /* DELT->snrDataDs containts deltSnr and deltSnrVn arrays */
+            DSL_CTX_NREAD(pContext, nErrCode,
+                          DELT->snrDataDs, *pData,
+                          sizeof(pContext->DELT->snrDataDs.nMeasurementTime) +
+                          sizeof(pContext->DELT->snrDataDs.nGroupSize) +
+                          sizeof(pContext->DELT->snrDataDs.deltSnr));
          }
          else
          {
-            DSL_CTX_READ(pContext, nErrCode, DELT->snrDataUs, pData);
+            DSL_CTX_NREAD(pContext, nErrCode,
+                          DELT->snrDataUs, *pData,
+                          sizeof(pContext->DELT->snrDataUs));
          }
       }
       else
@@ -1186,6 +1257,117 @@ DSL_Error_t DSL_DRV_DEV_G997_PowerManagementStateForcedTrigger(
    return nErrCode;
 }
 
+/*
+   For a detailed description please refer to the equivalent ioctl
+   \ref DSL_FIO_G997_ATTAINABLE_NDR_STATUS_GET
+*/
+DSL_Error_t DSL_DRV_DEV_G997_AttainableNdrStatusGet (
+   DSL_IN DSL_Context_t *pContext,
+   DSL_IN_OUT DSL_G997_AttainableNdrStatus_t *pData)
+{
+   DSL_Error_t nErrCode = DSL_SUCCESS;
+   DSL_LineStateValue_t nCurrentState = DSL_LINESTATE_UNKNOWN;
+
+   DSL_DEBUG(DSL_DBG_MSG, (pContext, SYS_DBG_MSG
+      "DSL[%02d]: IN - DSL_DRV_DEV_G997_AttainableNdrStatusGet"
+      DSL_DRV_CRLF, DSL_DEV_NUM(pContext)));
+
+   DSL_CHECK_POINTER(pContext, pData);
+   DSL_CHECK_ERR_CODE();
+
+   DSL_CHECK_DIRECTION(pData->nDirection);
+   DSL_CHECK_ERR_CODE();
+
+   if (pData->nDirection == DSL_UPSTREAM)
+   {
+      nErrCode = DSL_ERR_NOT_SUPPORTED_IN_US_DIRECTION;
+
+      DSL_DEBUG(DSL_DBG_ERR, (pContext, SYS_DBG_ERR
+         "DSL[%02d]: ERROR - Function is not supported for upstream!"
+         DSL_DRV_CRLF, DSL_DEV_NUM(pContext)));
+   }
+   else
+   {
+
+      DSL_CTX_READ_SCALAR(pContext, nErrCode, nLineState, nCurrentState);
+
+      if ((nCurrentState == DSL_LINESTATE_SHOWTIME_TC_SYNC) ||
+          (nCurrentState == DSL_LINESTATE_SHOWTIME_NO_SYNC) ||
+          (nCurrentState == DSL_LINESTATE_LOOPDIAGNOSTIC_COMPLETE))
+      {
+         nErrCode = DSL_DRV_VRX_AttainableNdrStatusGet(pContext, &(pData->data));
+      }
+      else
+      {
+         nErrCode = DSL_ERR_ONLY_AVAILABLE_IN_SHOWTIME;
+
+         DSL_DEBUG(DSL_DBG_ERR, (pContext, SYS_DBG_ERR "DSL[%02d]: ERROR - "
+            "Function is available for SHOWTIME and DIAGNOSTIC_COMPLETE!"
+            DSL_DRV_CRLF, DSL_DEV_NUM(pContext)));
+      }
+   }
+
+   DSL_DEBUG(DSL_DBG_MSG,
+      (pContext, SYS_DBG_MSG"DSL[%02d]: OUT - DSL_DRV_DEV_G997_AttainableNdrStatusGet, retCode=%d"
+      DSL_DRV_CRLF, DSL_DEV_NUM(pContext), nErrCode));
+
+   return nErrCode;
+}
+
+/*
+   For a detailed description please refer to the equivalent ioctl
+   \ref DSL_FIO_G997_RATE_ADAPTATION_STATUS_GET
+*/
+DSL_Error_t DSL_DRV_DEV_G997_RateAdaptationStatusGet(
+   DSL_IN DSL_Context_t *pContext,
+   DSL_IN_OUT DSL_G997_RateAdaptationStatus_t *pData)
+{
+   DSL_Error_t nErrCode = DSL_SUCCESS;
+   DSL_LineStateValue_t nCurrentState = DSL_LINESTATE_UNKNOWN;
+   ACK_RA_ModeDS_Get_t sAck;
+
+   memset(&sAck, 0x00, sizeof(ACK_RA_ModeDS_Get_t));
+
+   /* Get current line state*/
+   DSL_CTX_READ_SCALAR(pContext, nErrCode, nLineState, nCurrentState);
+
+   if ( (nCurrentState == DSL_LINESTATE_SHOWTIME_TC_SYNC) ||
+        (nCurrentState == DSL_LINESTATE_SHOWTIME_NO_SYNC) )
+   {
+      nErrCode = DSL_DRV_VRX_SendMsgRaModeGet(
+         pContext, pData->nDirection, (DSL_uint8_t*) &sAck);
+
+      if (nErrCode != DSL_SUCCESS)
+      {
+         return nErrCode;
+      }
+
+      pData->data.RA_MODE = (DSL_G997_RA_MODE_t)sAck.actRA_mode;
+
+      /* check retreived value*/
+      switch(pData->data.RA_MODE)
+      {
+         case DSL_G997_RA_MODE_MANUAL:
+         case DSL_G997_RA_MODE_AT_INIT:
+         case DSL_G997_RA_MODE_DYNAMIC:
+         case DSL_G997_RA_MODE_DYNAMIC_SOS:
+            break;
+
+         default:
+            DSL_DEBUG( DSL_DBG_ERR, (pContext,
+               SYS_DBG_ERR"DSL[%02d]: Unknown RA mode %u received from the FW!" DSL_DRV_CRLF,
+               DSL_DEV_NUM(pContext), sAck.actRA_mode));
+            nErrCode = DSL_ERR_PARAM_RANGE;
+         break;
+      }
+   }
+   else
+   {
+      nErrCode = DSL_ERR_ONLY_AVAILABLE_IN_SHOWTIME;
+   }
+
+   return nErrCode;
+}
 
 #ifdef __cplusplus
 }
