@@ -1,7 +1,7 @@
 /******************************************************************************
 
-                              Copyright (c) 2014
-                            Lantiq Deutschland GmbH
+                          Copyright (c) 2007-2015
+                     Lantiq Beteiligungs-GmbH & Co. KG
 
   For licensing information, see the file 'LICENSE' in the root folder of
   this software module.
@@ -26,7 +26,7 @@
    DSL CPE API in case of using RFC2662 and RFC3440
 */
 
-/** \defgroup DRV_DSL_CPE_API Lantiq DSL CPE API
+/** \defgroup DRV_DSL_CPE_API Intel DSL CPE API
     Lists the entire modules to the DSL CPE_API.
   @{ */
 
