@@ -1,7 +1,7 @@
 /******************************************************************************
 
-                              Copyright (c) 2014
-                            Lantiq Deutschland GmbH
+                          Copyright (c) 2007-2015
+                     Lantiq Beteiligungs-GmbH & Co. KG
 
   For licensing information, see the file 'LICENSE' in the root folder of
   this software module.
@@ -116,6 +116,12 @@ typedef enum
    /* *********************************************************************** */
    /* *** Common Error Codes                                              *** */
    /* *********************************************************************** */
+   /** The requested values are not supported in the upstream
+      (US) direction */
+   DSL_ERR_NOT_SUPPORTED_IN_US_DIRECTION = -45,
+   /** The requested values are not supported in the downstream
+      (DS) direction */
+   DSL_ERR_NOT_SUPPORTED_IN_DS_DIRECTION = -44,
    /** invalid DSL mode */
    DSL_ERR_NO_FIRMWARE_LOADED = -43,
    /** Data is currently not available.
