@@ -1,7 +1,7 @@
 /******************************************************************************
 
-                              Copyright (c) 2014
-                            Lantiq Deutschland GmbH
+                          Copyright (c) 2007-2015
+                     Lantiq Beteiligungs-GmbH & Co. KG
 
   For licensing information, see the file 'LICENSE' in the root folder of
   this software module.
@@ -25,7 +25,7 @@
  @{ */
 
 #ifndef DSL_PM_CHANNEL_15MIN_RECORDS_NUM
-/** history size - 15 minuntes channel records */
+/** history size - 15 minutes channel records */
 #define DSL_PM_CHANNEL_15MIN_RECORDS_NUM     2
 #endif
 
