@@ -1,7 +1,7 @@
 /******************************************************************************
 
-                              Copyright (c) 2014
-                            Lantiq Deutschland GmbH
+                          Copyright (c) 2007-2015
+                     Lantiq Beteiligungs-GmbH & Co. KG
 
   For licensing information, see the file 'LICENSE' in the root folder of
   this software module.
@@ -190,6 +190,7 @@ DSL_Error_t DSL_DRV_AutobootTimeoutSet(
 #define DSL_AUTOBOOT_HANDSHAKE_TIMEOUT_GOTO_V_STD 60
 #define DSL_AUTOBOOT_HANDSHAKE_TIMEOUT_GOTO_V_GHS 120
 #define DSL_AUTOBOOT_HANDSHAKE_TIMEOUT_GOTO_V_ANSI 180
+#define DSL_AUTOBOOT_HANDSHAKE_TIMEOUT_NO_PEER 240
 
 #ifdef __cplusplus
 }
