@@ -1,7 +1,7 @@
 /******************************************************************************
 
-                              Copyright (c) 2014
-                            Lantiq Deutschland GmbH
+                          Copyright (c) 2007-2015
+                     Lantiq Beteiligungs-GmbH & Co. KG
 
   For licensing information, see the file 'LICENSE' in the root folder of
   this software module.
@@ -189,7 +189,9 @@ extern const DSL_uint8_t DSL_g_dbgLvlNumber;
 extern const DSL_char_t* DSL_DBG_PRN_DIR[];
 extern const DSL_char_t* DSL_DBG_PRN_AUTOBOOT_STATUS[];
 extern const DSL_char_t* DSL_DBG_PRN_AUTOBOOT_STATE[];
-
+#ifdef INCLUDE_DSL_CPE_DEBUG_LOGGER_SUPPORT
+extern DSL_debugDestinations_t DSL_g_dbgDestination;
+#endif /* INCLUDE_DSL_CPE_DEBUG_LOGGER_SUPPORT */
 
 #endif /* ifdef DSL_DEBUG_DISABLE */
 
