@@ -1,7 +1,7 @@
 /******************************************************************************
 
-                              Copyright (c) 2014
-                            Lantiq Deutschland GmbH
+                          Copyright (c) 2007-2015
+                     Lantiq Beteiligungs-GmbH & Co. KG
 
   For licensing information, see the file 'LICENSE' in the root folder of
   this software module.
@@ -95,7 +95,16 @@ DSL_Error_t DSL_DRV_DEV_FwDownload
    DSL_uint32_t nSize2,
    DSL_int32_t *pLoff,
    DSL_int32_t *pCurrentOff,
-   DSL_boolean_t bLastChunk
+   DSL_boolean_t bLastChunk,
+   DSL_boolean_t bForceDownload
+);
+
+/** This function should be called to inform PP driver about selected TC
+    layer */
+DSL_Error_t DSL_DRV_DEV_MeiTcLayerSignaling
+(
+   DSL_Context_t *pContext,
+   DSL_TcLayerSelection_t nTcLayer
 );
 
 /** This function should be called to perform low level showtime entry/exit
@@ -181,20 +190,16 @@ DSL_Error_t DSL_DRV_DEV_LinkReset(
 #endif
 
 /**
-   This routine freezes a DSL line
+   This routine terminate all actions within firmware
 
    \param pContext
       pointer to the DSL context
-
-   \param pXTSE
-      pointer to the last XTSE configuration status
 */
 
 #ifndef SWIG
 
-DSL_Error_t DSL_DRV_DEV_LinkFreeze(
-   DSL_Context_t *pContext,
-   DSL_uint8_t *pXTSE
+DSL_Error_t DSL_DRV_DEV_LinkTerminate(
+   DSL_Context_t *pContext
 );
 
 #endif
