@@ -1,7 +1,7 @@
 /******************************************************************************
 
-                              Copyright (c) 2014
-                            Lantiq Deutschland GmbH
+                          Copyright (c) 2007-2015
+                     Lantiq Beteiligungs-GmbH & Co. KG
 
   For licensing information, see the file 'LICENSE' in the root folder of
   this software module.
@@ -182,6 +182,15 @@ DSL_Error_t DSL_DRV_DEV_G997_RateAdaptationStatusGet(
    DSL_IN DSL_Context_t *pContext,
    DSL_IN_OUT DSL_G997_RateAdaptationStatus_t *pData);
 
+/*
+   For a detailed description please refer to the equivalent ioctl
+   \ref DSL_FIO_G997_ATTAINABLE_NDR_STATUS_GET
+*/
+DSL_Error_t DSL_DRV_DEV_G997_AttainableNdrStatusGet(
+   DSL_IN DSL_Context_t *pContext,
+   DSL_IN_OUT DSL_G997_AttainableNdrStatus_t *pData);
+
+
 /** @} DRV_DSL_DEVICE */
 
 #ifdef __cplusplus
