@@ -1,7 +1,7 @@
 /******************************************************************************
 
-                              Copyright (c) 2014
-                            Lantiq Deutschland GmbH
+                          Copyright (c) 2007-2015
+                     Lantiq Beteiligungs-GmbH & Co. KG
 
   For licensing information, see the file 'LICENSE' in the root folder of
   this software module.
@@ -388,6 +388,10 @@ DSL_Error_t DSL_DRV_PM_DEV_HistoryIntervalAlign(
    DSL_Context_t *pContext);
 #endif /* INCLUDE_DSL_CPE_PM_HISTORY*/
 
+DSL_Error_t DSL_DRV_PM_DEV_ShowtimeCheckHandler(
+   DSL_IN DSL_Context_t *pContext,
+   DSL_OUT DSL_boolean_t *bMsgSendRequired);
+
 #endif /* #ifndef SWIG*/
 
 #ifdef __cplusplus
