@@ -1,7 +1,7 @@
 /******************************************************************************
 
-                              Copyright (c) 2014
-                            Lantiq Deutschland GmbH
+                          Copyright (c) 2007-2015
+                     Lantiq Beteiligungs-GmbH & Co. KG
 
   For licensing information, see the file 'LICENSE' in the root folder of
   this software module.
@@ -28,14 +28,9 @@
    /** MEI CPE driver interface header file*/
    #include "drv_mei_cpe_api_intern.h"
 
-#ifdef INCLUDE_DSL_ATM_PTM_INTERFACE_SUPPORT
-   #ifdef MEI_DRV_ATM_PTM_INTERFACE_ENABLE
-      #undef MEI_DRV_ATM_PTM_INTERFACE_ENABLE
-   #endif
-   #define MEI_DRV_ATM_PTM_INTERFACE_ENABLE 1
-   /** MEI CPE driver ATM/PTM interface header file*/
-   #include "drv_mei_cpe_api_atm_ptm_intern.h"
-#endif /* INCLUDE_DSL_ATM_PTM_INTERFACE_SUPPORT*/
+#if (DSL_DRV_ATM_PTM_INTERFACE_ENABLE == 1)
+#include "drv_mei_cpe_api_atm_ptm_intern.h"
+#endif /* #if (DSL_DRV_ATM_PTM_INTERFACE_ENABLE == 1) */
 
 #endif /* defined(DSL_CPE_SIMULATOR_DRIVER) && defined(WIN32)*/
 
@@ -70,7 +65,9 @@
 #define DSL_MIN_FW_VERSION_SRA_VDSL         5,   0,   4,  -1,  -1
 #define DSL_MIN_FW_VERSION_R6_RELEASE       6,  -1,  -1,  -1,  -1
 #define DSL_MIN_FW_VERSION_TC_STAT_ADSL     4,   0,   8,  -1,  -1
-#define DSL_MIN_FW_VERSION_RTXAMD2          7,   1,   1,   1,  -1
+#define DSL_MIN_FW_VERSION_NMS              8,   0, 0xA,  -1,  -1
+#define DSL_MIN_FW_VERSION_FE_DELT          8,   1,  -1,  -1,  -1
+#define DSL_MIN_FW_VERSION_R9_RELEASE       9,  -1,  -1,  -1,  -1
 
 /*
    Internal device dependent configuration options
@@ -88,8 +85,10 @@
    #define DSL_CHIPSET_TYPE_STRING "Lantiq-VRX200"
 #elif defined (DSL_VRX_DEVICE_VR10)
    #define DSL_CHIPSET_TYPE_STRING "Lantiq-VRX300"
+#elif defined (DSL_VRX_DEVICE_VR10_320)
+   #define DSL_CHIPSET_TYPE_STRING "Lantiq-VRX320"
 #else
-   #error Please defined a valid VRX device (VR9|VR10)!!!
+   #error Please defined a valid VRX device (VR9|VR10|VR10_320)!!!
 #endif
 
 /** Timeout setting for far end status in mili seconds */
@@ -309,6 +308,7 @@ typedef struct
    DSL_ActivationFsmConfigData_t nActivationCfg;
    DSL_boolean_t bT1_413;
    DSL_boolean_t bRemember;
+   DSL_boolean_t bMaskT1_413;
 
    DSL_uint8_t nSpar1;
    DSL_uint8_t nSpar2;
@@ -494,7 +494,7 @@ typedef struct
 #define DSL_DRV_VRX_InternalNfcEnable          MEI_InternalNfcEnable
 #define DSL_DRV_VRX_InternalNfcMsgRead         MEI_InternalNfcMsgRead
 #define DSL_DRV_VRX_InternalDebugLevelSet      MEI_InternalDebugLevelSet
-
+#define DSL_DRV_VRX_InternalCallbackSet        MEI_InternalCallbackSet
 #endif /* defined(DSL_CPE_SIMULATOR_DRIVER) && defined(WIN32)*/
 
 /**
@@ -597,6 +597,10 @@ DSL_Error_t DSL_DRV_VRX_G997_FramingParameterStatusAdslGet(
 #ifdef INCLUDE_DSL_SYSTEM_INTERFACE
 DSL_Error_t DSL_DRV_VRX_SystemInterfaceStatusUpdate(
    DSL_IN DSL_Context_t *pContext);
+
+DSL_Error_t DSL_DRV_VRX_SystemInterfaceStatusForceUpdate(
+   DSL_int32_t nDevice,
+   DSL_uint32_t nTcLayer);
 #endif
 
 #ifdef INCLUDE_DSL_G997_FRAMING_PARAMETERS
@@ -616,6 +620,10 @@ DSL_Error_t DSL_DRV_VRX_ShowtimeMeasurementUpdate(
 DSL_Error_t DSL_DRV_VRX_ShowtimeMeasurementCompleted(
    DSL_Context_t *pContext);
 
+DSL_Error_t DSL_DRV_VRX_AttainableNdrStatusGet(
+   DSL_Context_t *pContext,
+   DSL_G997_AttainableNdrStatusData_t *pData);
+
 /**
    Returns the smaller of the two parameters.
    Take care to use compatible types!
