@@ -1,7 +1,7 @@
 /******************************************************************************
 
-                              Copyright (c) 2014
-                            Lantiq Deutschland GmbH
+                          Copyright (c) 2007-2015
+                     Lantiq Beteiligungs-GmbH & Co. KG
 
   For licensing information, see the file 'LICENSE' in the root folder of
   this software module.
@@ -303,7 +303,7 @@ struct DSL_Context
    DSL_InteropFeatureConfigData_t interopFeatureConfigData;
 #endif /* INCLUDE_DSL_CPE_API_DANUBE*/
    /** Line features configuration data. for the UPSTREAM and DOWNSTREM direction*/
-   DSL_LineFeatureData_t lineFeatureDataCfg[DSL_ACCESSDIR_LAST];
+   DSL_LineFeatureData_t lineFeatureDataCfg[DSL_MODE_LAST][DSL_ACCESSDIR_LAST];
    /** Line features Status data. for the UPSTREAM and DOWNSTREM direction*/
    DSL_LineFeatureData_t lineFeatureDataSts[DSL_ACCESSDIR_LAST];
 
@@ -367,16 +367,6 @@ struct DSL_Context
    /**
       G997 Rate Adaptation Mode*/
    DSL_G997_RA_MODE_t rateAdaptationMode[DSL_MODE_LAST][DSL_ACCESSDIR_LAST];
-   /** Used for special handling within context of DSLCPE_SW-768 (VRX only).
-       It defines whether the API default configuration for SRA has to be
-       applied or not. Because SRA configuration for VDSL is currently
-       dependend on the FW capabilities the according detection can be only
-       done within context FW download (API might be started withou defined
-       FW!)
-       DSL_FALSE: Default API value was not set so far (initializtion value)
-       DSL_TRUE:  Default value was already set or manual user re-configuration
-       was done before which shall have the higher priority. */
-   DSL_boolean_t bDefaultRaModeSet;
 
    /** Line activation configuration. It will be applied during next
        link activation */
@@ -427,7 +417,7 @@ struct DSL_Context
    /**
    Structure to write (SET) or read (GET) the configuration of reboot criteria
    for restarting the link.*/
-   DSL_BF_RebootCriteriaConfigData_t RebootCriteriaNeConfigData;
+   DSL_BF_RebootCriteriaConfigData_t RebootCriteriaNeConfigData[DSL_MODE_LAST];
 
 #ifdef INCLUDE_DSL_DELT
    /** Pointer to DELT data storage */
@@ -515,6 +505,9 @@ struct DSL_Context
    /**
    Bonding Configuration Data*/
    DSL_BND_ConfigData_t BndConfig;
+   /**
+   Remote Bonding Configuration Data*/
+   DSL_BND_ConfigData_t RemoteBndConfig;
 #if (DSL_DRV_LINES_PER_DEVICE == 2)
    /**
    Bonding Port Mode sync Data*/
@@ -579,6 +572,31 @@ struct DSL_Context
          } \
       } while (0)
 
+   /** Macro to read values from the context in the safe way */
+   #define DSL_CTX_NREAD(ctx, err, attr, val, size) \
+      do { \
+         if ((size > sizeof(ctx->attr)) || (size > sizeof(val))) \
+         { \
+            DSL_DEBUG( DSL_DBG_ERR, (ctx, DSL_DRV_CRLF""DSL_DRV_CRLF"DSL_CTX_NREAD - copy size " \
+               "is too much! Data will be NOT copied!!!"DSL_DRV_CRLF)); \
+            err = DSL_ERR_MEMORY; \
+         } \
+         else \
+         { \
+            if(DSL_DRV_MUTEX_LOCK(ctx->dataMutex)) \
+            { \
+              DSL_DEBUG( DSL_DBG_ERR, (ctx, "Couldn't lock data mutex"DSL_DRV_CRLF)); \
+              err = DSL_ERR_SEMAPHORE_GET; \
+            } \
+            else \
+            { \
+               memcpy(&val, &ctx->attr, size); \
+               DSL_DRV_MUTEX_UNLOCK(ctx->dataMutex); \
+               err = DSL_SUCCESS; \
+            } \
+         } \
+      } while (0)
+
    /** Macro to read scalar values from the context in the safe way */
    #define DSL_CTX_READ_SCALAR(ctx, err, attr, val) \
       do { \
@@ -734,6 +752,20 @@ struct DSL_Context
          } \
       } while (0)
 
+   /* Macro to read values from the context in the safe way */
+   #define DSL_CTX_NREAD(ctx, err, attr, val, size)  do { \
+         if ((size > sizeof(ctx->attr)) || (size > sizeof(val))) \
+         { \
+            DSL_DEBUG( DSL_DBG_ERR, (ctx, DSL_DRV_CRLF""DSL_DRV_CRLF"DSL_CTX_NREAD - copy size " \
+               "is too much! Data will be NOT copied!!!"DSL_DRV_CRLF)); \
+            err = DSL_ERR_MEMORY; \
+         } \
+         else \
+         { \
+            err = _DSL_CTX_ASSIGN_ANY(ctx, &(ctx->attr), &(val), size); \
+         } \
+      } while (0)
+
    /* Macro to set values to context fields in the safe way */
    #define DSL_CTX_WRITE(ctx, err, attr, val) do { \
          if (sizeof(ctx->attr) != sizeof(val)) \
@@ -1435,6 +1467,38 @@ DSL_Error_t DSL_DRV_DBG_ModuleLevelGet(
 #endif
 #endif
 
+#ifdef INCLUDE_DSL_CPE_DEBUG_LOGGER_SUPPORT
+/**
+   For a detailed description please refer to the equivalent ioctl
+   \ref DSL_FIO_DBG_MODULE_DESTINATION_SET
+
+   \note CLI Debug functions should be not generated automatically
+*/
+#ifndef SWIG
+#ifndef DSL_DEBUG_DISABLE
+DSL_Error_t DSL_DRV_DBG_ModuleDestinationSet(
+   DSL_IN DSL_Context_t *pContext,
+   DSL_IN_OUT DSL_DBG_ModuleDestination_t *pData
+);
+#endif
+#endif
+
+/**
+   For a detailed description please refer to the equivalent ioctl
+   \ref DSL_FIO_DBG_MODULE_DESTINATION_GET
+
+   \note CLI Debug functions should be not generated automatically
+*/
+#ifndef SWIG
+#ifndef DSL_DEBUG_DISABLE
+DSL_Error_t DSL_DRV_DBG_ModuleDestinationGet(
+   DSL_IN DSL_Context_t *pContext,
+   DSL_IN_OUT DSL_DBG_ModuleDestination_t *pData
+);
+#endif
+#endif
+#endif /* INCLUDE_DSL_CPE_DEBUG_LOGGER_SUPPORT */
+
 /**
    For a detailed description please refer to the equivalent ioctl
    \ref DSL_FIO_DBG_DEVICE_MESSAGE_SEND
@@ -1604,18 +1668,14 @@ DSL_Error_t DSL_DRV_LinkReset(
 #endif
 
 /**
-   This routine freezes a DSL line
+   This routine terminate all actions within firmware
 
    \param pContext
       pointer to the DSL context
-
-   \param pXTSE
-      pointer to the last XTSE configuration status
 */
 #ifndef SWIG
-DSL_Error_t DSL_DRV_LinkFreeze(
-   DSL_Context_t *pContext,
-   DSL_uint8_t *pXTSE
+DSL_Error_t DSL_DRV_LinkTerminate(
+   DSL_Context_t *pContext
 );
 #endif
 
@@ -2017,7 +2077,8 @@ DSL_Error_t DSL_DRV_FwDownload(
    DSL_uint32_t nSize2,
    DSL_int32_t *pLoff,
    DSL_int32_t *pCurrentOff,
-   DSL_boolean_t bLastChunk
+   DSL_boolean_t bLastChunk,
+   DSL_boolean_t bForceDownload
 );
 #endif
 
@@ -2194,6 +2255,54 @@ DSL_Error_t  DSL_DRV_VRX_TestParamsFeCheck(
    DSL_Context_t *pContext);
 #endif
 
+#ifndef SWIG
+DSL_Error_t DSL_DRV_T1413_XTUO_RevisionStatusGet(
+   DSL_IN DSL_Context_t *pContext,
+   DSL_IN_OUT DSL_T1413RevisionStatus_t *pData);
+#endif
+
+#ifndef SWIG
+DSL_Error_t DSL_DRV_DEV_T1413_XTUO_RevisionStatusGet(
+   DSL_IN DSL_Context_t *pContext,
+   DSL_IN_OUT DSL_T1413RevisionStatusData_t *pData);
+#endif
+
+#ifndef SWIG
+DSL_Error_t DSL_DRV_T1413_XTUR_RevisionStatusGet(
+   DSL_IN DSL_Context_t *pContext,
+   DSL_IN_OUT DSL_T1413RevisionStatus_t *pData);
+#endif
+
+#ifndef SWIG
+DSL_Error_t DSL_DRV_DEV_T1413_XTUR_RevisionStatusGet(
+   DSL_IN DSL_Context_t *pContext,
+   DSL_IN_OUT DSL_T1413RevisionStatusData_t *pData);
+#endif
+
+#ifndef SWIG
+DSL_Error_t DSL_DRV_T1413_XTUO_VendorRevisionStatusGet(
+   DSL_IN DSL_Context_t *pContext,
+   DSL_IN_OUT DSL_T1413VendorRevisionStatus_t *pData);
+#endif
+
+#ifndef SWIG
+DSL_Error_t DSL_DRV_DEV_T1413_XTUO_VendorRevisionStatusGet(
+   DSL_IN DSL_Context_t *pContext,
+   DSL_IN_OUT DSL_T1413VendorRevisionStatusData_t *pData);
+#endif
+
+#ifndef SWIG
+DSL_Error_t DSL_DRV_T1413_XTUR_VendorRevisionStatusGet(
+   DSL_IN DSL_Context_t *pContext,
+   DSL_IN_OUT DSL_T1413VendorRevisionStatus_t *pData);
+#endif
+
+#ifndef SWIG
+DSL_Error_t DSL_DRV_DEV_T1413_XTUR_VendorRevisionStatusGet(
+   DSL_IN DSL_Context_t *pContext,
+   DSL_IN_OUT DSL_T1413VendorRevisionStatusData_t *pData);
+#endif
+
 /*
    DSL IOCTL handler helpers stuff
 */
@@ -2235,6 +2344,18 @@ typedef struct
 #define DSL_IOCTL_REGISTER(cmd, type, instance, func, argSz) \
            {cmd, type, instance, (DSL_void_t*)func, argSz}
 
+/** The type represents handler function prototype */
+typedef DSL_Error_t (*DSL_DRV_MsgIdHandler_t)(DSL_Context_t *, DSL_boolean_t *);
+
+/** Transimiting fw messages table definition */
+typedef struct DSL_VRX_PM_MsgCheck
+{
+   /** Firmware message id */
+   DSL_uint16_t nMsgId;
+   /** Function triggers nMsgId transmit conditions */
+   DSL_DRV_MsgIdHandler_t pMsgIdHandler;
+} DSL_VRX_PM_MsgCheck_t;
+
 #ifdef __cplusplus
 }
 #endif
