@@ -1,7 +1,7 @@
 /******************************************************************************
 
-                              Copyright (c) 2014
-                            Lantiq Deutschland GmbH
+                          Copyright (c) 2007-2015
+                     Lantiq Beteiligungs-GmbH & Co. KG
 
   For licensing information, see the file 'LICENSE' in the root folder of
   this software module.
@@ -568,6 +568,19 @@ DSL_Error_t DSL_DRV_G997_LineInitStatusGet(
 #endif
 #endif /* INCLUDE_DSL_G997_STATUS*/
 
+#ifdef INCLUDE_DSL_CPE_API_VRX
+/**
+   For a detailed description please refer to the equivalent ioctl
+   \ref DSL_FIO_G997_ATTAINABLE_NDR_STATUS_GET
+*/
+#ifndef SWIG_TMP
+DSL_Error_t DSL_DRV_G997_AttainableNdrStatusGet (
+   DSL_IN DSL_Context_t *pContext,
+   DSL_IN_OUT DSL_G997_AttainableNdrStatus_t *pData
+);
+#endif
+#endif /* #ifdef INCLUDE_DSL_CPE_API_VRX */
+
 /**
    For a detailed description please refer to the equivalent ioctl
    \ref DSL_FIO_G997_LINE_STATUS_GET
@@ -627,6 +640,17 @@ DSL_Error_t DSL_DRV_G997_RateAdaptationConfigGet(
 #endif
 #endif /* INCLUDE_DSL_CONFIG_GET*/
 
+#ifdef INCLUDE_DSL_CPE_API_VRX
+/*
+   For a detailed description please refer to the equivalent ioctl
+   \ref DSL_FIO_G997_RATE_ADAPTATION_STATUS_GET
+*/
+#ifndef SWIG_TMP
+DSL_Error_t DSL_DRV_G997_RateAdaptationStatusGet(
+   DSL_IN DSL_Context_t *pContext,
+   DSL_IN_OUT DSL_G997_RateAdaptationStatus_t *pData);
+#endif
+#endif /* INCLUDE_DSL_CPE_API_VRX */
 /**
    For a detailed description please refer to the equivalent ioctl
    \ref DSL_FIO_G997_CHANNEL_STATUS_GET
