@@ -1,7 +1,7 @@
 /******************************************************************************
 
-                              Copyright (c) 2014
-                            Lantiq Deutschland GmbH
+                          Copyright (c) 2007-2015
+                     Lantiq Beteiligungs-GmbH & Co. KG
 
   For licensing information, see the file 'LICENSE' in the root folder of
   this software module.
