@@ -1,7 +1,7 @@
 /******************************************************************************
 
-                              Copyright (c) 2014
-                            Lantiq Deutschland GmbH
+                          Copyright (c) 2007-2015
+                     Lantiq Beteiligungs-GmbH & Co. KG
 
   For licensing information, see the file 'LICENSE' in the root folder of
   this software module.
@@ -28,6 +28,13 @@
 #include "drv_dsl_cpe_vrx_msg_perf_pmd.h"
 #include "drv_dsl_cpe_vrx_msg_tc_counters.h"
 
+DSL_void_t DSL_DRV_VRX_DumpMessage(
+   DSL_Context_t *pContext,
+   const DSL_uint16_t nMsgId,
+   const DSL_uint16_t *pData,
+   const DSL_uint16_t nSize,
+   DSL_boolean_t bReceive);
+
 /**
    This function triggers to send a specified message which requests data from
    the local device and waits for appropriate answer.
@@ -128,6 +135,12 @@ DSL_Error_t DSL_DRV_VRX_SendMsgSnrGet(
    DSL_Context_t *pContext,
    const DSL_AccessDir_t nDirection,
    DSL_G997_NSCData8_t *pData);
+
+DSL_Error_t DSL_DRV_VRX_SendMsgSnrPerGroupesGet(
+   DSL_Context_t *pContext,
+   const DSL_AccessDir_t nDirection,
+   const DSL_uint8_t nGroupSize,
+   DSL_G997_NSCData8_t *pData);
 #endif /* defined(INCLUDE_DSL_G997_PER_TONE) || defined(INCLUDE_DSL_DELT)*/
 
 #ifdef INCLUDE_DSL_DELT
@@ -571,6 +584,21 @@ DSL_Error_t DSL_DRV_VRX_SendMsgTestParamsAuxGet(
 DSL_Error_t DSL_DRV_VRX_SendMsgSpar1Get(
    DSL_Context_t *pContext);
 
+/*
+   Reads the Far End xTSE capabilities from the device and stores it
+   into the internal structure.
+
+   \param pContext   Pointer to dsl library context structure, [I]
+
+   \return
+   Return values are defined within the DSL_Error_t definition
+   - DSL_SUCCESS in case of success
+   - DSL_ERROR if operation failed
+*/
+DSL_Error_t DSL_DRV_VRX_SendMsgFeVectoringSupportGet(
+   DSL_Context_t *pContext,
+   DSL_boolean_t *bFeVectSup);
+
 #ifdef INCLUDE_DSL_G997_LINE_INVENTORY
 /*
    Reads the Far End xTSE capabilities from the device and stores it
@@ -947,6 +975,22 @@ DSL_Error_t DSL_DRV_VRX_SendMsgModemFsmOptions2Set(
    DSL_Context_t *pContext,
    DSL_boolean_t bEnableVirtualNoise);
 
+/*
+   This function sends the VRX firmware message CMD_PAF_PME_ID_Set
+
+   \param pContext - Pointer to DSL CPE library context structure, [I]
+
+   \param nPmeId - PME identification number
+
+   \return
+   Return values are defined within the DSL_Error_t definition
+   - DSL_SUCCESS in case of success
+   - DSL_ERROR if operation failed
+*/
+DSL_Error_t DSL_DRV_VRX_SendMsgPmeIdSet(
+   DSL_Context_t *pContext,
+   const DSL_uint16_t nPmeId);
+
 /*
    This function sends the firmware message "CMD_HS_ToneGroupSet".
    It configures the hand shake tone set according to the given config.
@@ -994,38 +1038,6 @@ DSL_Error_t DSL_DRV_VRX_SendMsgOrderlyShutDownRequest(
    DSL_Context_t *pContext);
 #endif /* INCLUDE_DSL_CPE_API_VRX */
 
-/**
-   This function sends the VRX firmware undefined message
-   to freeze TX link
-
-   \param pContext - Pointer to DSL library context structure,
-   \param nVal  - firmware internal value
-
-   \return
-   Return values are defined within the DSL_Error_t definition
-   - DSL_SUCCESS in case of success
-   - DSL_ERROR if operation failed
-*/
-DSL_Error_t DSL_DRV_VRX_SendMsgLinkFreezeTX(
-   DSL_Context_t *pContext,
-   const DSL_uint16_t nVal);
-
-/**
-   This function sends the VRX firmware undefined message
-   to freeze RX link
-
-   \param pContext - Pointer to DSL library context structure,
-   \param nVal  - firmware internal value
-
-   \return
-   Return values are defined within the DSL_Error_t definition
-   - DSL_SUCCESS in case of success
-   - DSL_ERROR if operation failed
-*/
-DSL_Error_t DSL_DRV_VRX_SendMsgLinkFreezeRX(
-   DSL_Context_t *pContext,
-   const DSL_uint16_t nVal);
-
 /**
    This function sends the VRX firmware message CMD_VersionInfoGet.
 
@@ -1095,6 +1107,10 @@ DSL_Error_t DSL_DRV_VRX_SendMsgMiscConfigSet(
 DSL_Error_t DSL_DRV_VRX_SendMsgTestOptionsSet(
    DSL_Context_t *pContext);
 
+DSL_Error_t DSL_DRV_VRX_SendMsgAttndrStatusGet(
+   DSL_Context_t *pContext,
+   DSL_uint8_t *pAck);
+
 /** @} DRV_DSL_DEVICE */
 
 #ifdef INCLUDE_DSL_SYSTEM_INTERFACE
@@ -1114,6 +1130,84 @@ DSL_Error_t DSL_DRV_VRX_SendMsgTcStatusGet(
    DSL_uint8_t *pAck);
 #endif
 
+/**
+   This function requests the actual active upstream/downstream RA mode
+   (ACT-RA-MODEus, Section 7.5.1.33.2 of G.997.1).
+
+   \param pContext - Pointer to DSL library context structure, [I]
+   \param nDirection - specifies direction, [I]
+   \param pAck - Pointer to the msg ACK, [O]
+
+   \return
+   Return values are defined within the DSL_Error_t definition
+   - DSL_SUCCESS in case of success
+   - DSL_ERROR if operation failed
+*/
+DSL_Error_t DSL_DRV_VRX_SendMsgRaModeGet(
+   DSL_Context_t *pContext,
+   DSL_AccessDir_t nDirection,
+   DSL_uint8_t *pAck);
+
+/**
+   This function requests the xTU-O T1.413 Revision Number
+
+   pContext - Pointer to DSL library context structure, [I]
+   \param pAck - Pointer to the msg ACK, [O]
+
+   \return
+   Return values are defined within the DSL_Error_t definition
+   - DSL_SUCCESS in case of success
+   - DSL_ERROR if operation failed
+*/
+DSL_Error_t DSL_DRV_VRX_SendMsgT1413_XTUO_RevisionGet(
+   DSL_Context_t *pContext,
+   DSL_uint8_t *pAck);
+
+/**
+   This function requests the xTU-R T1.413 Revision Number
+
+   pContext - Pointer to DSL library context structure, [I]
+   \param pAck - Pointer to the msg ACK, [O]
+
+   \return
+   Return values are defined within the DSL_Error_t definition
+   - DSL_SUCCESS in case of success
+   - DSL_ERROR if operation failed
+*/
+DSL_Error_t DSL_DRV_VRX_SendMsgT1413_XTUR_RevisionGet(
+   DSL_Context_t *pContext,
+   DSL_uint8_t *pAck);
+
+/**
+   This function requests the xTU-O T1.413 Vendor Revision Number
+
+   pContext - Pointer to DSL library context structure, [I]
+   \param pAck - Pointer to the msg ACK, [O]
+
+   \return
+   Return values are defined within the DSL_Error_t definition
+   - DSL_SUCCESS in case of success
+   - DSL_ERROR if operation failed
+*/
+DSL_Error_t DSL_DRV_VRX_SendMsgT1413_XTUO_VendorRevisionGet(
+   DSL_Context_t *pContext,
+   DSL_uint8_t *pAck);
+
+/**
+   This function requests the xTU-R T1.413 Vendor Revision Number
+
+   pContext - Pointer to DSL library context structure, [I]
+   \param pAck - Pointer to the msg ACK, [O]
+
+   \return
+   Return values are defined within the DSL_Error_t definition
+   - DSL_SUCCESS in case of success
+   - DSL_ERROR if operation failed
+*/
+DSL_Error_t DSL_DRV_VRX_SendMsgT1413_XTUR_VendorRevisionGet(
+   DSL_Context_t *pContext,
+   DSL_uint8_t *pAck);
+
 #ifdef __cplusplus
 }
 #endif
