@@ -1,7 +1,7 @@
 /******************************************************************************
 
-                              Copyright (c) 2014
-                            Lantiq Deutschland GmbH
+                          Copyright (c) 2007-2015
+                     Lantiq Beteiligungs-GmbH & Co. KG
 
   For licensing information, see the file 'LICENSE' in the root folder of
   this software module.
@@ -22,6 +22,11 @@
 #include <linux/ctype.h>
 #include <linux/version.h>
 #include <linux/spinlock.h>
+#ifdef INCLUDE_DSL_CPE_DEBUG_LOGGER_SUPPORT
+#include <linux/skbuff.h>
+#include <linux/netlink.h>
+#include <net/sock.h>
+#endif
 
 #if (LINUX_VERSION_CODE < KERNEL_VERSION(2,6,33))
    #include <linux/autoconf.h>
@@ -47,7 +52,9 @@
 #include <linux/poll.h>
 #include <asm/uaccess.h>
 #if (LINUX_VERSION_CODE < KERNEL_VERSION(3,8,0))
+#ifndef DSL_VRX_DEVICE_VR10_320
    #include <linux/smp_lock.h>
+#endif
 #else
 #include <linux/smp.h>
 #endif
