@@ -1,7 +1,7 @@
 /******************************************************************************
 
-                              Copyright (c) 2014
-                            Lantiq Deutschland GmbH
+                          Copyright (c) 2007-2015
+                     Lantiq Beteiligungs-GmbH & Co. KG
 
   For licensing information, see the file 'LICENSE' in the root folder of
   this software module.
@@ -139,6 +139,16 @@ typedef struct VRX_PSD_TxDS VRX_PSD_TxDS_t;
 
 /**
 
+*/
+typedef struct VRX_PSDbreak2 VRX_PSDbreak2_t;
+
+/**
+
+*/
+typedef struct VRX_PSD_CompBreak VRX_PSD_CompBreak_t;
+
+/**
+
 */
 typedef struct VRX_RxRef2PSD VRX_RxRef2PSD_t;
 
@@ -281,6 +291,44 @@ struct VRX_PSD_TxDS
 } __PACKED__ ;
 
 
+/**
+
+*/
+struct VRX_PSDbreak2
+{
+#if DSL_BYTE_ORDER == DSL_BIG_ENDIAN
+   /** Tone Index of Breakpoint */
+   DSL_uint16_t toneIndex;
+   /** PSD Level of Breakpoint */
+   DSL_uint16_t level;
+#else
+   /** Tone Index of Breakpoint */
+   DSL_uint16_t toneIndex;
+   /** PSD Level of Breakpoint */
+   DSL_uint16_t level;
+#endif
+} __PACKED__ ;
+
+
+/**
+
+*/
+struct VRX_PSD_CompBreak
+{
+#if DSL_BYTE_ORDER == DSL_BIG_ENDIAN
+   /** Tone Index of Breakpoint */
+   DSL_uint16_t toneIndex;
+   /** Compensation Level of Breakpoint */
+   DSL_int16_t level;
+#else
+   /** Tone Index of Breakpoint */
+   DSL_uint16_t toneIndex;
+   /** Compensation Level of Breakpoint */
+   DSL_int16_t level;
+#endif
+} __PACKED__ ;
+
+
 /**
 
 */
