@@ -1,7 +1,7 @@
 /******************************************************************************
 
-                              Copyright (c) 2014
-                            Lantiq Deutschland GmbH
+                          Copyright (c) 2007-2015
+                     Lantiq Beteiligungs-GmbH & Co. KG
 
   For licensing information, see the file 'LICENSE' in the root folder of
   this software module.
@@ -195,8 +195,8 @@ typedef struct CMD_CRC_StatsNE_Get CMD_CRC_StatsNE_Get_t;
 /**
    Returns near-end CRC counter values. (Section 7.2.2.1.1 of G.997.1). These
    are wrap-around counters which are not affected by the TR1-period.The
-   "LP1/Fast Path" parameters are fed only in ADSL1 mode with selected fast
-   path.
+   "LP1/Fast Path" parameters are fed only in ADSL1 and ADSL1 Lite mode with
+   selected fast path.
 */
 typedef struct ACK_CRC_StatsNE_Get ACK_CRC_StatsNE_Get_t;
 
@@ -215,7 +215,8 @@ typedef struct CMD_CRC_StatsFE_Get CMD_CRC_StatsFE_Get_t;
 /**
    Returns far-end CRC counter values. (Section 7.2.2.2.1 of G.997.1). These are
    wrap-around counters which are not affected by the TR1-period.The "LP1/Fast
-   Path" parameters are fed only in ADSL1 mode with selected fast path.
+   Path" parameters are fed only in ADSL1 and ADSL1 Lite mode with selected fast
+   path.
 */
 typedef struct ACK_CRC_StatsFE_Get ACK_CRC_StatsFE_Get_t;
 
@@ -234,7 +235,8 @@ typedef struct CMD_FEC_StatsNE_Get CMD_FEC_StatsNE_Get_t;
 /**
    Returns near-end FEC counter values (Section 7.2.2.1.2 of G.997.1). These are
    wrap-around counters which are not affected by the TR1-period.The "LP1/Fast
-   Path" parameters are fed only in ADSL1 mode with selected fast path.
+   Path" parameters are fed only in ADSL1 and ADSL1 Lite mode with selected fast
+   path.
 */
 typedef struct ACK_FEC_StatsNE_Get ACK_FEC_StatsNE_Get_t;
 
@@ -253,7 +255,8 @@ typedef struct CMD_FEC_StatsFE_Get CMD_FEC_StatsFE_Get_t;
 /**
    Returns far-end FEC counter values (Section 7.2.2.2.2 of G.997.1). These are
    wrap-around counters which are not affected by the TR1-period.The "LP1/Fast
-   Path" parameters are fed only in ADSL1 mode with selected fast path.
+   Path" parameters are fed only in ADSL1 and ADSL1 Lite mode with selected fast
+   path.
 */
 typedef struct ACK_FEC_StatsFE_Get ACK_FEC_StatsFE_Get_t;
 
@@ -312,8 +315,8 @@ typedef struct ACK_LinePerfCountNE_Set ACK_LinePerfCountNE_Set_t;
 
 /**
    Writes the near-end CRC counter values (Section 7.2.2.1.1 of G.997.1)The
-   "LP1/Fast Path" parameters are used only in ADSL1 mode with selected "Fast
-   Path".
+   "LP1/Fast Path" parameters are used only in ADSL1 and ADSL1 Lite mode with
+   selected "Fast Path".
 */
 typedef struct CMD_CRC_StatsNE_Set CMD_CRC_StatsNE_Set_t;
 
@@ -330,8 +333,8 @@ typedef struct ACK_CRC_StatsNE_Set ACK_CRC_StatsNE_Set_t;
 
 /**
    Writes near-end FEC counter values. (Section 7.2.2.1.2 of G.997.1)The
-   "LP1/Fast Path" parameters are used only in ADSL1 mode with selected "Fast
-   Path".
+   "LP1/Fast Path" parameters are used only in ADSL1 and ADSL1 Lite mode with
+   selected "Fast Path".
 */
 typedef struct CMD_FEC_StatsNE_Set CMD_FEC_StatsNE_Set_t;
 
@@ -952,8 +955,8 @@ struct CMD_CRC_StatsNE_Get
 /**
    Returns near-end CRC counter values. (Section 7.2.2.1.1 of G.997.1). These
    are wrap-around counters which are not affected by the TR1-period.The
-   "LP1/Fast Path" parameters are fed only in ADSL1 mode with selected fast
-   path.
+   "LP1/Fast Path" parameters are fed only in ADSL1 and ADSL1 Lite mode with
+   selected fast path.
 */
 struct ACK_CRC_StatsNE_Get
 {
@@ -1010,7 +1013,8 @@ struct CMD_CRC_StatsFE_Get
 /**
    Returns far-end CRC counter values. (Section 7.2.2.2.1 of G.997.1). These are
    wrap-around counters which are not affected by the TR1-period.The "LP1/Fast
-   Path" parameters are fed only in ADSL1 mode with selected fast path.
+   Path" parameters are fed only in ADSL1 and ADSL1 Lite mode with selected fast
+   path.
 */
 struct ACK_CRC_StatsFE_Get
 {
@@ -1067,7 +1071,8 @@ struct CMD_FEC_StatsNE_Get
 /**
    Returns near-end FEC counter values (Section 7.2.2.1.2 of G.997.1). These are
    wrap-around counters which are not affected by the TR1-period.The "LP1/Fast
-   Path" parameters are fed only in ADSL1 mode with selected fast path.
+   Path" parameters are fed only in ADSL1 and ADSL1 Lite mode with selected fast
+   path.
 */
 struct ACK_FEC_StatsNE_Get
 {
@@ -1156,7 +1161,8 @@ struct CMD_FEC_StatsFE_Get
 /**
    Returns far-end FEC counter values (Section 7.2.2.2.2 of G.997.1). These are
    wrap-around counters which are not affected by the TR1-period.The "LP1/Fast
-   Path" parameters are fed only in ADSL1 mode with selected fast path.
+   Path" parameters are fed only in ADSL1 and ADSL1 Lite mode with selected fast
+   path.
 */
 struct ACK_FEC_StatsFE_Get
 {
@@ -1173,16 +1179,6 @@ struct ACK_FEC_StatsFE_Get
    DSL_uint16_t cntFEC_LSW;
    /** Far-End FEC Count LP1, MSW */
    DSL_uint16_t cntFEC_MSW;
-   /** Reserved */
-   DSL_uint16_t Res0[4];
-   /** Far-End Total RS CW Count LP0, LSW */
-   DSL_uint16_t cntECI_CW_LSW;
-   /** Far-End Total RS CW Count LP0, MSW */
-   DSL_uint16_t cntECI_CW_MSW;
-   /** Far-End Total RS CW Count LP1, LSW */
-   DSL_uint16_t cntECF_CW_LSW;
-   /** Far-End Total RS CW Count LP1, MSW */
-   DSL_uint16_t cntECF_CW_MSW;
 #else
    /** Index */
    DSL_uint16_t Index;
@@ -1196,16 +1192,6 @@ struct ACK_FEC_StatsFE_Get
    DSL_uint16_t cntFEC_LSW;
    /** Far-End FEC Count LP1, MSW */
    DSL_uint16_t cntFEC_MSW;
-   /** Reserved */
-   DSL_uint16_t Res0[4];
-   /** Far-End Total RS CW Count LP0, LSW */
-   DSL_uint16_t cntECI_CW_LSW;
-   /** Far-End Total RS CW Count LP0, MSW */
-   DSL_uint16_t cntECI_CW_MSW;
-   /** Far-End Total RS CW Count LP1, LSW */
-   DSL_uint16_t cntECF_CW_LSW;
-   /** Far-End Total RS CW Count LP1, MSW */
-   DSL_uint16_t cntECF_CW_MSW;
 #endif
 } __PACKED__ ;
 
@@ -1384,8 +1370,8 @@ struct ACK_LinePerfCountNE_Set
 
 /**
    Writes the near-end CRC counter values (Section 7.2.2.1.1 of G.997.1)The
-   "LP1/Fast Path" parameters are used only in ADSL1 mode with selected "Fast
-   Path".
+   "LP1/Fast Path" parameters are used only in ADSL1 and ADSL1 Lite mode with
+   selected "Fast Path".
 */
 struct CMD_CRC_StatsNE_Set
 {
@@ -1440,8 +1426,8 @@ struct ACK_CRC_StatsNE_Set
 
 /**
    Writes near-end FEC counter values. (Section 7.2.2.1.2 of G.997.1)The
-   "LP1/Fast Path" parameters are used only in ADSL1 mode with selected "Fast
-   Path".
+   "LP1/Fast Path" parameters are used only in ADSL1 and ADSL1 Lite mode with
+   selected "Fast Path".
 */
 struct CMD_FEC_StatsNE_Set
 {
