@@ -1,7 +1,7 @@
 /******************************************************************************
 
-                              Copyright (c) 2014
-                            Lantiq Deutschland GmbH
+                          Copyright (c) 2007-2015
+                     Lantiq Beteiligungs-GmbH & Co. KG
 
   For licensing information, see the file 'LICENSE' in the root folder of
   this software module.
@@ -313,16 +313,12 @@ DSL_Error_t DSL_DRV_PM_DEV_ChannelCountersGet(
    sCmd.CrcStatsFE.Index  = sCmd.CrcStatsNE.Index  = 0x0;
    sCmd.CrcStatsFE.Length = sCmd.CrcStatsNE.Length = 4;
 
-   /* skip fw exchange during training */
-   if (pContext->bGotShowtime)
-   {
-      /* Get Code Violations*/
-      nErrCode = DSL_DRV_VRX_SendMessage(
-         pContext,
-         nDirection == DSL_NEAR_END ? CMD_CRC_STATSNE_GET : CMD_CRC_STATSFE_GET,
-         sizeof(sCmd.CrcStatsNE), (DSL_uint8_t*)&(sCmd.CrcStatsNE),
-         sizeof(sAck.CrcStatsNE), (DSL_uint8_t*)&(sAck.CrcStatsNE));
-   }
+   /* Get Code Violations*/
+   nErrCode = DSL_DRV_VRX_SendMessage(
+      pContext,
+      nDirection == DSL_NEAR_END ? CMD_CRC_STATSNE_GET : CMD_CRC_STATSFE_GET,
+      sizeof(sCmd.CrcStatsNE), (DSL_uint8_t*)&(sCmd.CrcStatsNE),
+      sizeof(sAck.CrcStatsNE), (DSL_uint8_t*)&(sAck.CrcStatsNE));
 
    /* Check nErrCode and return on error*/
    if( nErrCode < 0 )
@@ -347,16 +343,12 @@ DSL_Error_t DSL_DRV_PM_DEV_ChannelCountersGet(
    sCmd.FecStatsFE.Index  = sCmd.FecStatsNE.Index  = 0x0;
    sCmd.FecStatsFE.Length = sCmd.FecStatsNE.Length = 12;
 
-   /* skip fw exchange during training */
-   if (pContext->bGotShowtime)
-   {
-      /* Get Forward Error Corrections*/
-      nErrCode = DSL_DRV_VRX_SendMessage(
-         pContext,
-         nDirection == DSL_NEAR_END ? CMD_FEC_STATSNE_GET : CMD_FEC_STATSFE_GET,
-         sizeof(sCmd.FecStatsNE), (DSL_uint8_t*)&(sCmd.FecStatsNE),
-         sizeof(sAck.FecStatsNE), (DSL_uint8_t*)&(sAck.FecStatsNE));
-   }
+   /* Get Forward Error Corrections*/
+   nErrCode = DSL_DRV_VRX_SendMessage(
+      pContext,
+      nDirection == DSL_NEAR_END ? CMD_FEC_STATSNE_GET : CMD_FEC_STATSFE_GET,
+      sizeof(sCmd.FecStatsNE), (DSL_uint8_t*)&(sCmd.FecStatsNE),
+      sizeof(sAck.FecStatsNE), (DSL_uint8_t*)&(sAck.FecStatsNE));
 
    /* Check nErrCode and return on error*/
    if( nErrCode < 0 )
@@ -613,15 +605,11 @@ DSL_Error_t DSL_DRV_PM_DEV_DataPathCountersGet(
          sCmd.cmdPtmStatsGet.Index  = 0x0;
          sCmd.cmdPtmStatsGet.Length = 8;
 
-         /* skip fw exchange during training */
-         if (pContext->bGotShowtime)
-         {
-            /* Get PTM statistics*/
-            nErrCode = DSL_DRV_VRX_SendMessage(
-               pContext, CMD_PTM_BC0_STATSNE_GET,
-               sizeof(sCmd.cmdPtmStatsGet), (DSL_uint8_t*)&(sCmd.cmdPtmStatsGet),
-               sizeof(sAck.ackPtmStatsGet), (DSL_uint8_t*)&(sAck.ackPtmStatsGet));
-         }
+         /* Get PTM statistics*/
+         nErrCode = DSL_DRV_VRX_SendMessage(
+            pContext, CMD_PTM_BC0_STATSNE_GET,
+            sizeof(sCmd.cmdPtmStatsGet), (DSL_uint8_t*)&(sCmd.cmdPtmStatsGet),
+            sizeof(sAck.ackPtmStatsGet), (DSL_uint8_t*)&(sAck.ackPtmStatsGet));
 
          /* Check nErrCode and return on error*/
          if( nErrCode < 0 )
@@ -646,15 +634,11 @@ DSL_Error_t DSL_DRV_PM_DEV_DataPathCountersGet(
          sCmd.cmdAtmStatsNE_Get.Index  = 0x0;
          sCmd.cmdAtmStatsNE_Get.Length = 8;
 
-         /* skip fw exchange during training */
-         if (pContext->bGotShowtime)
-         {
-            /* Get ATM statistics*/
-            nErrCode = DSL_DRV_VRX_SendMessage(
-               pContext, CMD_ATM_BC0_STATSNE_GET,
-               sizeof(sCmd.cmdAtmStatsNE_Get), (DSL_uint8_t*)&(sCmd.cmdAtmStatsNE_Get),
-               sizeof(sAck.ackAtmStatsNE_Get), (DSL_uint8_t*)&(sAck.ackAtmStatsNE_Get));
-         }
+         /* Get ATM statistics*/
+         nErrCode = DSL_DRV_VRX_SendMessage(
+            pContext, CMD_ATM_BC0_STATSNE_GET,
+            sizeof(sCmd.cmdAtmStatsNE_Get), (DSL_uint8_t*)&(sCmd.cmdAtmStatsNE_Get),
+            sizeof(sAck.ackAtmStatsNE_Get), (DSL_uint8_t*)&(sAck.ackAtmStatsNE_Get));
 
          /* Check nErrCode and return on error*/
          if( nErrCode < 0 )
@@ -678,15 +662,11 @@ DSL_Error_t DSL_DRV_PM_DEV_DataPathCountersGet(
          sCmd.cmdAtmTxStatsGet.Index  = 0;
          sCmd.cmdAtmTxStatsGet.Length = 0x4;
 
-         /* skip fw exchange during training */
-         if (pContext->bGotShowtime)
-         {
-            /* Get ATM Tx statistics*/
-            nErrCode = DSL_DRV_VRX_SendMessage(
-               pContext, CMD_ATM_BC0_TXSTATSNE_GET,
-               sizeof(sCmd.cmdAtmTxStatsGet), (DSL_uint8_t*)&(sCmd.cmdAtmTxStatsGet),
-               sizeof(sAck.ackAtmTxStatsGet), (DSL_uint8_t*)&(sAck.ackAtmTxStatsGet));
-         }
+         /* Get ATM Tx statistics*/
+         nErrCode = DSL_DRV_VRX_SendMessage(
+            pContext, CMD_ATM_BC0_TXSTATSNE_GET,
+            sizeof(sCmd.cmdAtmTxStatsGet), (DSL_uint8_t*)&(sCmd.cmdAtmTxStatsGet),
+            sizeof(sAck.ackAtmTxStatsGet), (DSL_uint8_t*)&(sAck.ackAtmTxStatsGet));
 
          /* Check nErrCode and return on error*/
          if( nErrCode < 0 )
@@ -712,15 +692,11 @@ DSL_Error_t DSL_DRV_PM_DEV_DataPathCountersGet(
          sCmd.cmdAtmStatsFE_Get.Index  = 0x0;
          sCmd.cmdAtmStatsFE_Get.Length = 8;
 
-         /* skip fw exchange during training */
-         if (pContext->bGotShowtime)
-         {
-            /* Get ATM statistics*/
-            nErrCode = DSL_DRV_VRX_SendMessage(
-               pContext, CMD_ATM_BC0_STATSFE_GET,
-               sizeof(sCmd.cmdAtmStatsFE_Get), (DSL_uint8_t*)&(sCmd.cmdAtmStatsFE_Get),
-               sizeof(sAck.ackAtmStatsFE_Get), (DSL_uint8_t*)&(sAck.ackAtmStatsFE_Get));
-         }
+         /* Get ATM statistics*/
+         nErrCode = DSL_DRV_VRX_SendMessage(
+            pContext, CMD_ATM_BC0_STATSFE_GET,
+            sizeof(sCmd.cmdAtmStatsFE_Get), (DSL_uint8_t*)&(sCmd.cmdAtmStatsFE_Get),
+            sizeof(sAck.ackAtmStatsFE_Get), (DSL_uint8_t*)&(sAck.ackAtmStatsFE_Get));
 
          /* Check nErrCode and return on error*/
          if( nErrCode < 0 )
@@ -1001,7 +977,6 @@ DSL_Error_t DSL_DRV_PM_DEV_LineSecCountersGet(
    {
       sCmd.NE.Length = 10;
 
-      /* do not skip fw exchange during training because of UAS counter*/
       nErrCode = DSL_DRV_VRX_SendMessage(
          pContext,
          nDirection == DSL_NEAR_END ? CMD_LINEPERFCOUNTNE_GET : CMD_LINEPERFCOUNTFE_GET,
@@ -1028,7 +1003,6 @@ DSL_Error_t DSL_DRV_PM_DEV_LineSecCountersGet(
    {
       sCmd.NE.Length = 10;
 
-      /* do not skip fw exchange during training because of UAS counter*/
       nErrCode = DSL_DRV_VRX_SendMessage(
          pContext,
          nDirection == DSL_NEAR_END ? CMD_LINEPERFCOUNTNE_GET : CMD_LINEPERFCOUNTFE_GET,
@@ -1436,7 +1410,10 @@ DSL_Error_t DSL_DRV_PM_DEV_ReTxCountersGet(
          return nErrCode;
       }
 
-      if (nDirection == DSL_NEAR_END)
+      /* EFTR has different handling for NE and FE   */
+      /* FE  =>  CMD/ACK_RTX_PM_US_Get::EFTR_min_xxx */
+      /* NE  =>  CMD/ACK_RTX_PM_DS_Get::EFTR_xxx     */
+      if (nDirection == DSL_FAR_END)
       {
          pCounters->nErrorFreeBits = ((DSL_uint32_t)(retxPm.US.ErrorFreeBits_MSW << 16)) |
                                                      retxPm.US.ErrorFreeBits_LSW;
@@ -1590,4 +1567,37 @@ DSL_Error_t DSL_DRV_PM_DEV_HistoryIntervalAlign(
 }
 #endif /* INCLUDE_DSL_CPE_PM_HISTORY*/
 
+DSL_Error_t DSL_DRV_PM_DEV_ShowtimeCheckHandler(
+   DSL_Context_t *pContext,
+   DSL_boolean_t *bMsgSendRequired)
+{
+   DSL_Error_t nErrCode = DSL_SUCCESS;
+   DSL_LineStateValue_t nLineState;
+
+   /* Get device line state*/
+   nErrCode = DSL_DRV_DEV_LineStateGet(pContext, &nLineState);
+   if( nErrCode != DSL_SUCCESS )
+   {
+      DSL_DEBUG( DSL_DBG_ERR,
+         (pContext, SYS_DBG_ERR"DSL[%02d]: ERROR - Line state get failed!"
+         DSL_DRV_CRLF, DSL_DEV_NUM(pContext)));
+
+      return nErrCode;
+   }
+
+   if((nLineState == DSL_LINESTATE_SHOWTIME_NO_SYNC) ||
+      (nLineState == DSL_LINESTATE_SHOWTIME_TC_SYNC) ||
+      /* save PM counters at fail state */
+      (nLineState == DSL_LINESTATE_EXCEPTION))
+   {
+      *bMsgSendRequired = DSL_TRUE;
+   }
+   else
+   {
+      *bMsgSendRequired = DSL_FALSE;
+   }
+
+   return nErrCode;
+}
+
 #endif /* #ifdef defined(INCLUDE_DSL_CPE_API_VRX) && defined(INCLUDE_DSL_PM) */
